@@ -58,6 +58,7 @@
 
 static int getTracks(const char *fname, int *tracks)
 {
+    KRFUNC;
     int ret = 0;
     memset(tracks, 0, 200*sizeof(int));
 
@@ -105,6 +106,9 @@ public:
 KIso::KIso(const QString& filename, const QString & _mimetype)
         : KArchive(0L)
 {
+    KRFUNC;
+    KRDEBUG("Starting KIso: " << filename << " - type: " << _mimetype);
+
     m_startsec = -1;
     m_filename = filename;
     d = new KIsoPrivate;
@@ -156,6 +160,8 @@ KIso::KIso(const QString& filename, const QString & _mimetype)
 void KIso::prepareDevice(const QString & filename,
                          const QString & mimetype, bool forced)
 {
+    KRFUNC;
+    KRDEBUG("Preparing: " << filename << " - type: " << mimetype << " - using the force: " << forced);
     /* 'hack' for Qt's false assumption that only S_ISREG is seekable */
     if ("inode/blockdevice" == mimetype)
         setDevice(new QFileHack(filename));
@@ -199,6 +205,7 @@ KIso::~KIso()
 /* callback function for libisofs */
 static int readf(char *buf, unsigned int start, unsigned int len, void *udata)
 {
+    KRFUNC;
 
     QIODevice* dev = (static_cast<KIso*>(udata))->device();
 
@@ -213,6 +220,7 @@ static int readf(char *buf, unsigned int start, unsigned int len, void *udata)
 /* callback function for libisofs */
 static int mycallb(struct iso_directory_record *idr, void *udata)
 {
+    KRFUNC;
 
     KIso *iso = static_cast<KIso*>(udata);
     QString path, user, group, symlink;
@@ -300,6 +308,7 @@ static int mycallb(struct iso_directory_record *idr, void *udata)
 
 void KIso::addBoot(struct el_torito_boot_descriptor* bootdesc)
 {
+    KRFUNC;
 
     int i;
     long long size;
@@ -337,6 +346,7 @@ void KIso::addBoot(struct el_torito_boot_descriptor* bootdesc)
 
 void KIso::readParams()
 {
+    KRFUNC;
     KConfig *config;
 
     config = new KConfig("kio_isorc");
@@ -349,6 +359,7 @@ void KIso::readParams()
 
 bool KIso::openArchive(QIODevice::OpenMode mode)
 {
+    KRFUNC;
     iso_vol_desc *desc;
     QString path, uid, gid;
     QT_STATBUF buf;
@@ -450,6 +461,7 @@ bool KIso::openArchive(QIODevice::OpenMode mode)
 
 bool KIso::closeArchive()
 {
+    KRFUNC;
     d->dirList.clear();
     return true;
 }
