@@ -37,6 +37,8 @@
 #include <KIO/Job>
 #include <KIOCore/KFileItem>
 
+#include <errno.h>
+
 #define MAX_IPC_SIZE           (1024*32)
 #define TRIES_WITH_PASSWORDS   3
 
@@ -453,7 +455,7 @@ void kio_krarcProtocol::get(const QUrl &url, int tries)
 
         QString escapedFilename = file;
         if(arcType == "zip") // left bracket needs to be escaped
-            escapedFilename.replace("[", "[[]");
+            escapedFilename.replace('[', "[[]");
         proc << getCmd << getPath(arcFile->url());
         if (arcType != "gzip" && arcType != "bzip2" && arcType != "lzma" && arcType != "xz") proc << localeEncodedString(escapedFilename);
         connect(&proc, SIGNAL(newOutputData(KProcess *, QByteArray &)),
@@ -724,7 +726,7 @@ void kio_krarcProtocol::copy(const QUrl &url, const QUrl &dest, int, KIO::JobFla
             QString escapedFilename = file;
             if(arcType == "zip") {
                 // left bracket needs to be escaped
-                escapedFilename.replace("[", "[[]");
+                escapedFilename.replace('[', "[[]");
             }
 
             KrLinecountingProcess proc;
@@ -756,10 +758,41 @@ void kio_krarcProtocol::copy(const QUrl &url, const QUrl &dest, int, KIO::JobFla
     if (!dest.isLocalFile())
         KRDEBUG("ERROR: " << url.path() << " is not a local file.");
 
-    // CMD_COPY is no more in KF5 - replaced with 74 value (as stated in kio/src/core/commands_p.h, which could be found in quickgit.kde.org/?p=kio.git&a=tree)
+    // CMD_COPY is no more in KF5 - replaced with 74 value (as stated in kio/src/core/commands_p.h, which could be found in cgit.kde.org/kio.git/tree)
     error(ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(mProtocol, 74));
 }
 
+void kio_krarcProtocol::rename(const QUrl& src, const QUrl& dest, KIO::JobFlags flags)
+{
+    KRDEBUG("renaming from: " << src.path() << " to: " << dest.path());
+    KRDEBUG("command: " << arcPath);
+
+    if (!checkWriteSupport()) {
+        return;
+    }
+
+    if (renCmd.isEmpty()) {
+        error(KIO::ERR_CANNOT_RENAME, src.fileName());
+        return;
+    }
+
+    if (src.fileName() == dest.fileName()) {
+        return;
+    }
+
+    KrLinecountingProcess proc;
+    proc << renCmd << arcPath << src.path().replace(arcPath + '/', "") << dest.path().replace(arcPath + '/', "");
+    proc.start();
+    proc.waitForFinished();
+
+    if (proc.exitStatus() != QProcess::NormalExit || !checkStatus(proc.exitCode()))  {
+        error(KIO::ERR_CANNOT_RENAME, src.fileName());
+        return;
+    }
+
+    finished();
+}
+
 void kio_krarcProtocol::listDir(const QUrl &url)
 {
     KRFUNC;
@@ -1479,6 +1512,7 @@ bool kio_krarcProtocol::initArcParameters()
     copyCmd = QStringList();
     delCmd  = QStringList();
     putCmd  = QStringList();
+    renCmd  = QStringList();
 
     if (arcType == "zip") {
         noencoding = true;
@@ -1495,6 +1529,10 @@ bool kio_krarcProtocol::initArcParameters()
             putCmd  << fullPathName("zip") << "-ry";
         }
 
+        if (!QStandardPaths::findExecutable(QStringLiteral("7za")).isEmpty()) {
+            renCmd  << fullPathName("7za") << "rn";
+        }
+
         if (!getPassword().isEmpty()) {
             getCmd  << "-P" << password;
             copyCmd << "-P" << password;
@@ -1609,6 +1647,7 @@ bool kio_krarcProtocol::initArcParameters()
         copyCmd << cmd << "e" << "-y";
         delCmd  << cmd << "d" << "-y";
         putCmd  << cmd << "a" << "-y";
+        renCmd  << cmd << "rn";
         if (!getPassword().isEmpty()) {
             getCmd  << QString("-p%1").arg(password);
             listCmd << QString("-p%1").arg(password);
