@@ -59,6 +59,7 @@
 #include <KWidgetsAddons/KMessageBox>
 #include <KIO/Global>
 #include <KCompletion/KHistoryComboBox>
+#include <KWidgetsAddons/KStandardGuiItem>
 
 #include "../defaults.h"
 #include "../krglobal.h"
@@ -95,8 +96,8 @@ PackGUIBase::PackGUIBase(QWidget* parent)
 
     typeData = new QComboBox(this);
     typeData->setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed));
-    connect(typeData, SIGNAL(activated(const QString &)), this,  SLOT(checkConsistency()));
-    connect(typeData, SIGNAL(highlighted(const QString &)), this,  SLOT(checkConsistency()));
+    connect(typeData, SIGNAL(activated(QString)), this,  SLOT(checkConsistency()));
+    connect(typeData, SIGNAL(highlighted(QString)), this,  SLOT(checkConsistency()));
     hbox->addWidget(typeData);
 
     grid->addLayout(hbox, 1, 0);
@@ -241,7 +242,7 @@ PackGUIBase::PackGUIBase(QWidget* parent)
 
     password = new QLineEdit(advancedWidget);
     password->setEchoMode(QLineEdit::Password);
-    connect(password, SIGNAL(textChanged(const QString &)), this, SLOT(checkConsistency()));
+    connect(password, SIGNAL(textChanged(QString)), this, SLOT(checkConsistency()));
 
     passwordGrid->addWidget(password, 0, 1);
 
@@ -251,7 +252,7 @@ PackGUIBase::PackGUIBase(QWidget* parent)
 
     passwordAgain = new QLineEdit(advancedWidget);
     passwordAgain->setEchoMode(QLineEdit::Password);
-    connect(passwordAgain, SIGNAL(textChanged(const QString &)), this, SLOT(checkConsistency()));
+    connect(passwordAgain, SIGNAL(textChanged(QString)), this, SLOT(checkConsistency()));
 
     passwordGrid->addWidget(passwordAgain, 1, 1);
 
@@ -309,23 +310,18 @@ PackGUIBase::PackGUIBase(QWidget* parent)
     QSpacerItem* spacer_2 = new QSpacerItem(140, 20, QSizePolicy::Expanding, QSizePolicy::Fixed);
     hbox_6->addItem(spacer_2);
 
-    queueButton = new QPushButton(this);
-    queueButton->setText(i18n("F2 Queue"));
-    hbox_6->addWidget(queueButton);
-
     okButton = new QPushButton(this);
-    okButton->setText(i18n("OK"));
+    KStandardGuiItem::assign(okButton, KStandardGuiItem::Ok);
     okButton->setDefault(true);
     hbox_6->addWidget(okButton);
 
     cancelButton = new QPushButton(this);
-    cancelButton->setText(i18n("Cancel"));
+    KStandardGuiItem::assign(cancelButton, KStandardGuiItem::Cancel);
     hbox_6->addWidget(cancelButton);
 
     grid->addLayout(hbox_6, 6, 0);
 
     // signals and slots connections
-    connect(queueButton, SIGNAL(clicked()), this, SLOT(slotQueue()));
     connect(okButton, SIGNAL(clicked()), this, SLOT(accept()));
     connect(advancedButton, SIGNAL(clicked()), this, SLOT(expand()));
     connect(cancelButton, SIGNAL(clicked()), this, SLOT(reject()));
@@ -504,20 +500,3 @@ bool PackGUIBase::extraProperties(QMap<QString, QString> & inMap)
     }
     return true;
 }
-
-void PackGUIBase::slotQueue()
-{
-    accept();
-}
-
-void PackGUIBase::keyPressEvent(QKeyEvent *e)
-{
-    switch (e->key()) {
-    case Qt::Key_F2:
-        slotQueue();
-        return;
-    default:
-        QDialog::keyPressEvent(e);
-    }
-}
-
