@@ -55,11 +55,12 @@
 #include <KConfigCore/KSharedConfig>
 #include <KI18n/KLocalizedString>
 #include <KWidgetsAddons/KMessageBox>
+#include <KWidgetsAddons/KStandardGuiItem>
 #include <KIO/Job>
 #include <KIO/DeleteJob>
 
-#include "../VFS/krpermhandler.h"
-#include "../VFS/krvfshandler.h"
+#include "../FileSystem/krpermhandler.h"
+#include "../FileSystem/filesystemprovider.h"
 #include "../kicons.h"
 #include "../defaults.h"
 #include "../krglobal.h"
@@ -166,7 +167,7 @@ LoaderWidget::LoaderWidget(QWidget *parent) : QScrollArea(parent), cancelled(fal
     QSpacerItem* spacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);
     hbox->addItem(spacer);
     QPushButton *cancelButton = new QPushButton(hboxWidget);
-    cancelButton->setText(i18n("Cancel"));
+    KStandardGuiItem::assign(cancelButton, KStandardGuiItem::Cancel);
     hbox->addWidget(cancelButton);
 
     synchGrid->addWidget(hboxWidget, 6, 1);
@@ -186,7 +187,7 @@ void LoaderWidget::init()
 
 void LoaderWidget::setCurrentURL(const QUrl &url)
 {
-    searchedDirectory->setText(vfs::ensureTrailingSlash(url).toDisplayString(QUrl::PreferLocalFile));
+    searchedDirectory->setText(FileSystem::ensureTrailingSlash(url).toDisplayString(QUrl::PreferLocalFile));
 }
 
 void LoaderWidget::setValues(int fileNum, int dirNum, KIO::filesize_t total)
@@ -203,7 +204,7 @@ void LoaderWidget::slotCancelled()
 
 DiskUsage::DiskUsage(QString confGroup, QWidget *parent) : QStackedWidget(parent),
         currentDirectory(0), root(0), configGroup(confGroup), loading(false),
-        abortLoading(false), clearAfterAbort(false), deleting(false), searchVfs(0)
+        abortLoading(false), clearAfterAbort(false), deleting(false), searchFileSystem(0)
 {
     listView = new DUListView(this);
     lineView = new DULines(this);
@@ -241,9 +242,6 @@ DiskUsage::~DiskUsage()
 
 void DiskUsage::load(const QUrl &baseDir)
 {
-    if (searchVfs && !searchVfs->vfs_canDelete()) {
-        return;
-    }
 
     fileNum = dirNum = 0;
     currentSize = 0;
@@ -262,19 +260,19 @@ void DiskUsage::load(const QUrl &baseDir)
     directoryStack.push("");
     parentStack.push(root);
 
-    if (searchVfs) {
-        delete searchVfs;
-        searchVfs = 0;
+    if (searchFileSystem) {
+        delete searchFileSystem;
+        searchFileSystem = 0;
     }
-    searchVfs = KrVfsHandler::getVfs(baseDir);
-    if (searchVfs == 0) {
+    searchFileSystem = FileSystemProvider::instance().getFilesystem(baseDir);
+    if (searchFileSystem == 0) {
+        krOut << "diskusage could not get filesystem for directory " << baseDir;
         loading = abortLoading = clearAfterAbort = false;
         emit loadFinished(false);
         return;
     }
 
-    searchVfs->vfs_setQuiet(true);
-    currentVfile = 0;
+    currentFileItem = 0;
 
     if (!loading) {
         viewBeforeLoad = activeView;
@@ -293,17 +291,12 @@ void DiskUsage::load(const QUrl &baseDir)
 
 void DiskUsage::slotLoadDirectory()
 {
-    if (searchVfs && !searchVfs->vfs_canDelete()) {  // recursive call from slotLoadDirectory?
-        loadingTimer.setSingleShot(true);
-        loadingTimer.start(100);                       // as it can cause crash, ignore it and wait while
-        return;                                        // the recursion finishes
-    }
-    if ((currentVfile == 0 && directoryStack.isEmpty()) || loaderView->wasCancelled() || abortLoading) {
-        if (searchVfs)
-            delete searchVfs;
+    if ((currentFileItem == 0 && directoryStack.isEmpty()) || loaderView->wasCancelled() || abortLoading) {
+        if (searchFileSystem)
+            delete searchFileSystem;
 
-        searchVfs = 0;
-        currentVfile = 0;
+        searchFileSystem = 0;
+        currentFileItem = 0;
 
         setView(viewBeforeLoad);
 
@@ -319,7 +312,7 @@ void DiskUsage::slotLoadDirectory()
         loading = abortLoading = clearAfterAbort = false;
     } else if (loading) {
         for (int counter = 0; counter != MAX_FILENUM; counter ++) {
-            if (currentVfile == 0) {
+            if (currentFileItem == 0) {
                 if (directoryStack.isEmpty())
                     break;
 
@@ -345,35 +338,36 @@ void DiskUsage::slotLoadDirectory()
 
                 loaderView->setCurrentURL(url);
 
-                if (!searchVfs->vfs_refresh(url))
+                if (!searchFileSystem->refresh(url))
                     break;
+                fileItems = searchFileSystem->fileItems();
 
                 dirNum++;
 
-                currentVfile = searchVfs->vfs_getFirstFile();
+                currentFileItem = fileItems.isEmpty() ? 0 : fileItems.takeFirst();
             } else {
                 fileNum++;
                 File *newItem = 0;
 
-                QString mime = currentVfile->vfile_getMime(true); // fast == not using mimetype magic
+                QString mime = currentFileItem->getMime(); // fast == not using mimetype magic
 
-                if (currentVfile->vfile_isDir() && !currentVfile->vfile_isSymLink()) {
-                    newItem = new Directory(currentParent, currentVfile->vfile_getName(), dirToCheck, currentVfile->vfile_getSize(),
-                                            currentVfile->vfile_getMode(), currentVfile->vfile_getOwner(), currentVfile->vfile_getGroup(),
-                                            currentVfile->vfile_getPerm(), currentVfile->vfile_getTime_t(), currentVfile->vfile_isSymLink(),
+                if (currentFileItem->isDir() && !currentFileItem->isSymLink()) {
+                    newItem = new Directory(currentParent, currentFileItem->getName(), dirToCheck, currentFileItem->getSize(),
+                                            currentFileItem->getMode(), currentFileItem->getOwner(), currentFileItem->getGroup(),
+                                            currentFileItem->getPerm(), currentFileItem->getTime_t(), currentFileItem->isSymLink(),
                                             mime);
-                    directoryStack.push((dirToCheck.isEmpty() ? "" : dirToCheck + '/') + currentVfile->vfile_getName());
+                    directoryStack.push((dirToCheck.isEmpty() ? "" : dirToCheck + '/') + currentFileItem->getName());
                     parentStack.push(dynamic_cast<Directory *>(newItem));
                 } else {
-                    newItem = new File(currentParent, currentVfile->vfile_getName(), dirToCheck, currentVfile->vfile_getSize(),
-                                       currentVfile->vfile_getMode(), currentVfile->vfile_getOwner(), currentVfile->vfile_getGroup(),
-                                       currentVfile->vfile_getPerm(), currentVfile->vfile_getTime_t(), currentVfile->vfile_isSymLink(),
+                    newItem = new File(currentParent, currentFileItem->getName(), dirToCheck, currentFileItem->getSize(),
+                                       currentFileItem->getMode(), currentFileItem->getOwner(), currentFileItem->getGroup(),
+                                       currentFileItem->getPerm(), currentFileItem->getTime_t(), currentFileItem->isSymLink(),
                                        mime);
-                    currentSize += currentVfile->vfile_getSize();
+                    currentSize += currentFileItem->getSize();
                 }
                 currentParent->append(newItem);
 
-                currentVfile = searchVfs->vfs_getNextFile();
+                currentFileItem = fileItems.isEmpty() ? 0 : fileItems.takeFirst();
             }
         }
 
@@ -585,20 +579,21 @@ int DiskUsage::del(File *file, bool calcPercents, int depth)
         // now ask the user if he want to delete:
         KConfigGroup ga(krConfig, "Advanced");
         if (ga.readEntry("Confirm Delete", _ConfirmDelete)) {
-            QString s, b;
+            QString s;
+            KGuiItem b;
             if (trash && url.isLocalFile()) {
                 s = i18nc("singularOnly", "Do you really want to move this item to the trash?");
-                b = i18n("&Trash");
+                b = KGuiItem(i18n("&Trash"));
             } else {
                 s = i18nc("singularOnly", "Do you really want to delete this item?");
-                b = i18n("&Delete");
+                b = KStandardGuiItem::del();
             }
 
             QStringList name;
             name.append(file->fullPath());
             // show message
             // note: i'm using continue and not yes/no because the yes/no has cancel as default button
-            if (KMessageBox::warningContinueCancelList(krMainWindow, s, name, i18n("Warning"), KGuiItem(b)) != KMessageBox::Continue)
+            if (KMessageBox::warningContinueCancelList(krMainWindow, s, name, i18n("Warning"), b) != KMessageBox::Continue)
                 return 0;
         }
 
