@@ -31,18 +31,18 @@
 #define KRVIEW_H
 
 // QtCore
-#include <QVariant>
 #include <QHash>
-#include <QRegExp>
 #include <QList>
 #include <QModelIndex>
+#include <QRegExp>
 #include <QTimer>
+#include <QVariant>
 // QtGui
-#include <QPixmap>
 #include <QDropEvent>
+#include <QPixmap>
 
-#include "../VFS/krquery.h"
 #include "../Filter/filtersettings.h"
+#include "../FileSystem/krquery.h"
 
 #define MAX_BRIEF_COLS 5
 
@@ -50,9 +50,9 @@ class KrView;
 class KrViewItem;
 class KrPreviews;
 class KrViewInstance;
-class VfileContainer;
+class DirListerInterface;
 
-typedef QList<KrViewItem*> KrViewItemList;
+typedef QList<KrViewItem *> KrViewItemList;
 
 // KrViewProperties
 // This class is an interface class between KrView and KrViewItem
@@ -64,49 +64,67 @@ typedef QList<KrViewItem*> KrViewItemList;
 // Every property that the item needs to know about the view must be here!
 class KrViewProperties
 {
-public:
-    KrViewProperties() :
-        numericPermissions(false),
-        displayIcons(false),
-        sortColumn(Name),
-        sortOptions(static_cast<SortOptions>(0)),
-        sortMethod(Alphabetical),
-        filter(KrViewProperties::All),
-        filterMask(KRQuery("*")),
-        filterApplysToDirs(false),
-        localeAwareCompareIsCaseSensitive(false),
-        humanReadableSize(),
-        numberOfColumns(1)
-    {}
+  public:
+    KrViewProperties()
+        : numericPermissions(false), displayIcons(false), sortColumn(Name),
+          sortOptions(static_cast<SortOptions>(0)), sortMethod(Alphabetical),
+          filter(KrViewProperties::All), filterMask(KRQuery("*")), filterApplysToDirs(false),
+          localeAwareCompareIsCaseSensitive(false), humanReadableSize(), numberOfColumns(1)
+    {
+    }
 
-    enum PropertyType { NoProperty = 0x0, PropIconSize = 0x1, PropShowPreviews = 0x2,
-                        PropSortMode = 0x4, PropColumns = 0x8, PropFilter = 0x10,
-                        AllProperties = PropIconSize | PropShowPreviews | PropSortMode | PropColumns | PropFilter
-                      };
-    enum ColumnType { NoColumn = -1, Name = 0x0, Ext = 0x1, Size = 0x2, Type = 0x3, Modified = 0x4,
-                      Permissions = 0x5, KrPermissions = 0x6, Owner = 0x7, Group = 0x8, MAX_COLUMNS = 0x09
-                    };
-    enum SortOptions { Descending = 0x200, DirsFirst = 0x400, IgnoreCase = 0x800,
-                       AlwaysSortDirsByName = 0x1000, LocaleAwareSort = 0x2000
-                     };
-    enum SortMethod { Alphabetical = 0x1, AlphabeticalNumbers = 0x2,
-                      CharacterCode = 0x4, CharacterCodeNumbers = 0x8, Krusader = 0x10
-                    };
+    enum PropertyType {
+        NoProperty = 0x0,
+        PropIconSize = 0x1,
+        PropShowPreviews = 0x2,
+        PropSortMode = 0x4,
+        PropColumns = 0x8,
+        PropFilter = 0x10,
+        AllProperties = PropIconSize | PropShowPreviews | PropSortMode | PropColumns | PropFilter
+    };
+    enum ColumnType {
+        NoColumn = -1,
+        Name = 0x0,
+        Ext = 0x1,
+        Size = 0x2,
+        Type = 0x3,
+        Modified = 0x4,
+        Permissions = 0x5,
+        KrPermissions = 0x6,
+        Owner = 0x7,
+        Group = 0x8,
+        MAX_COLUMNS = 0x09
+    };
+    enum SortOptions {
+        Descending = 0x200,
+        DirsFirst = 0x400,
+        IgnoreCase = 0x800,
+        AlwaysSortDirsByName = 0x1000,
+        LocaleAwareSort = 0x2000
+    };
+    enum SortMethod {
+        Alphabetical = 0x1,
+        AlphabeticalNumbers = 0x2,
+        CharacterCode = 0x4,
+        CharacterCodeNumbers = 0x8,
+        Krusader = 0x10
+    };
     enum FilterSpec { Dirs = 0x1, Files = 0x2, All = 0x3, Custom = 0x4 };
 
-    bool numericPermissions;        // show full permission column as octal numbers
-    bool displayIcons; // true if icons should be displayed in this view
+    bool numericPermissions; // show full permission column as octal numbers
+    bool displayIcons;       // true if icons should be displayed in this view
     ColumnType sortColumn;
     SortOptions sortOptions;
-    SortMethod sortMethod;  // sort method for names and extensions
-    FilterSpec filter; // what items to show (all, custom, exec)
-    KRQuery filterMask; // what items to show (*.cpp, *.h etc)
+    SortMethod sortMethod; // sort method for names and extensions
+    FilterSpec filter;     // what items to show (all, custom, exec)
+    KRQuery filterMask;    // what items to show (*.cpp, *.h etc)
     FilterSettings filterSettings;
     bool filterApplysToDirs;
     bool localeAwareCompareIsCaseSensitive; // mostly, it is not! depends on LC_COLLATE
-    bool humanReadableSize;  // display size as KB, MB or just as a long number
-    QStringList atomicExtensions; // list of strings, which will be treated as one extension. Must start with a dot.
-    int numberOfColumns;    // the number of columns in the brief view
+    bool humanReadableSize;                 // display size as KB, MB or just as a long number
+    QStringList atomicExtensions; // list of strings, which will be treated as one extension. Must
+                                  // start with a dot.
+    int numberOfColumns;          // the number of columns in the brief view
 };
 
 // operator can handle two ways of doing things:
@@ -114,85 +132,42 @@ public:
 // 2. if the view HAS A widget (a krview-son has a member of klistview)
 // this is done by specifying the view and the widget in the constructor,
 // even if they are actually the same object (specify it twice in that case)
-class KrViewOperator: public QObject
+class KrViewOperator : public QObject
 {
     Q_OBJECT
 public:
     KrViewOperator(KrView *view, QWidget *widget);
     ~KrViewOperator();
 
-    KrView *view() const {
-        return _view;
-    }
-    QWidget *widget() const {
-        return _widget;
-    }
+    KrView *view() const { return _view; }
+    QWidget *widget() const { return _widget; }
     void startDrag();
 
-    void emitGotDrop(QDropEvent *e) {
-        emit gotDrop(e);
-    }
-    void emitLetsDrag(QStringList items, QPixmap icon) {
-        emit letsDrag(items, icon);
-    }
-    void emitItemDescription(QString &desc) {
-        emit itemDescription(desc);
-    }
-    void emitContextMenu(const QPoint &point) {
-        emit contextMenu(point);
-    }
-    void emitEmptyContextMenu(const QPoint &point) {
-        emit emptyContextMenu(point);
-    }
+    void emitGotDrop(QDropEvent *e) { emit gotDrop(e); }
+    void emitLetsDrag(QStringList items, QPixmap icon) { emit letsDrag(items, icon); }
+    void emitItemDescription(const QString &desc) { emit itemDescription(desc); }
+    void emitContextMenu(const QPoint &point) { emit contextMenu(point); }
+    void emitEmptyContextMenu(const QPoint &point) { emit emptyContextMenu(point); }
     void emitRenameItem(const QString &oldName, const QString &newName) {
         emit renameItem(oldName, newName);
     }
-    void emitExecuted(const QString &name) {
-        emit executed(name);
-    }
-    void emitGoInside(const QString &name) {
-        emit goInside(name);
-    }
-    void emitNeedFocus() {
-        emit needFocus();
-    }
-    void emitMiddleButtonClicked(KrViewItem *item) {
-        emit middleButtonClicked(item);
-    }
-    void emitCurrentChanged(KrViewItem *item) {
-        emit currentChanged(item);
-    }
-    void emitPreviewJobStarted(KJob *job) {
-        emit previewJobStarted(job);
-    }
-    void emitGoHome() {
-        emit goHome();
-    }
-    void emitDirUp() {
-        emit dirUp();
-    }
-    void emitDeleteFiles(bool reallyDelete) {
-        emit deleteFiles(reallyDelete);
-    }
-    void emitCalcSpace(KrViewItem *item) {
-        emit calcSpace(item);
-    }
-    void emitRefreshActions() {
-        emit refreshActions();
-    }
-    void emitGoBack() {
-        emit goBack();
-    }
-    void emitGoForward() {
-        emit goForward();
-    }
+    void emitExecuted(const QString &name) { emit executed(name); }
+    void emitGoInside(const QString &name) { emit goInside(name); }
+    void emitNeedFocus() { emit needFocus(); }
+    void emitMiddleButtonClicked(KrViewItem *item) { emit middleButtonClicked(item); }
+    void emitCurrentChanged(KrViewItem *item) { emit currentChanged(item); }
+    void emitPreviewJobStarted(KJob *job) { emit previewJobStarted(job); }
+    void emitGoHome() { emit goHome(); }
+    void emitDirUp() { emit dirUp(); }
+    void emitDefaultDeleteFiles(bool invertMode) { emit defaultDeleteFiles(invertMode); }
+    void emitRefreshActions() { emit refreshActions(); }
+    void emitGoBack() { emit goBack(); }
+    void emitGoForward() { emit goForward(); }
 
     bool searchItem(const QString &, bool, int = 0); // search for item and set cursor
-    bool filterSearch(const QString &, bool); // filter view items
+    bool filterSearch(const QString &, bool);        // filter view items
     void setMassSelectionUpdate(bool upd);
-    bool isMassSelectionUpdate() {
-        return _massSelectionUpdate;
-    }
+    bool isMassSelectionUpdate() { return _massSelectionUpdate; }
     void settingsChanged(KrViewProperties::PropertyType properties);
 
 public slots:
@@ -205,9 +180,9 @@ signals:
     void selectionChanged();
     void gotDrop(QDropEvent *e);
     void letsDrag(QStringList items, QPixmap icon);
-    void itemDescription(QString &desc);
+    void itemDescription(const QString &desc);
     void contextMenu(const QPoint &point);
-    void emptyContextMenu(const QPoint& point);
+    void emptyContextMenu(const QPoint &point);
     void renameItem(const QString &oldName, const QString &newName);
     void executed(const QString &name);
     void goInside(const QString &name);
@@ -216,9 +191,8 @@ signals:
     void currentChanged(KrViewItem *item);
     void previewJobStarted(KJob *job);
     void goHome();
-    void deleteFiles(bool reallyDelete);
+    void defaultDeleteFiles(bool invertMode);
     void dirUp();
-    void calcSpace(KrViewItem *item);
     void refreshActions();
     void goBack();
     void goForward();
@@ -227,10 +201,9 @@ protected slots:
     void saveDefaultSettings();
     void startUpdate();
     void cleared();
-    // for signals from vfs' dirwatch
-    void fileAdded(vfile *vf);
-    void fileDeleted(const QString& name);
-    void fileUpdated(vfile *vf);
+
+    void fileAdded(FileItem *fileitem);
+    void fileUpdated(FileItem *fileitem);
 
 protected:
     // never delete those
@@ -268,14 +241,12 @@ class KrView
 {
     friend class KrViewItem;
     friend class KrViewOperator;
-public:
 
+public:
     class IconSizes : public QVector<int>
     {
-    public:
-        IconSizes() : QVector<int>() {
-            *this << 12 << 16 << 22 << 32 << 48 << 64 << 128 << 256;
-        }
+      public:
+        IconSizes() : QVector<int>() { *this << 12 << 16 << 22 << 32 << 48 << 64 << 128 << 256; }
     };
 
     // instantiating a new view
@@ -283,21 +254,14 @@ public:
     // 2. view->init()
     // notes: constructor does as little as possible, setup() does the rest. esp, note that
     // if you need something from operator or properties, move it into setup()
-    virtual void init();
-    KrViewInstance *instance() {
-        return &_instance;
-    }
-
+    void init(bool enableUpdateDefaultSettings = true);
+    KrViewInstance *instance() { return &_instance; }
     static const IconSizes iconSizes;
 
 protected:
-    virtual void initProperties();
-    virtual KrViewProperties * createViewProperties() {
-        return new KrViewProperties();
-    }
-    virtual KrViewOperator *createOperator() {
-        return new KrViewOperator(this, _widget);
-    }
+    void initProperties();
+    KrViewProperties *createViewProperties() { return new KrViewProperties(); }
+    KrViewOperator *createOperator() { return new KrViewOperator(this, _widget); }
     virtual void setup() = 0;
 
     ///////////////////////////////////////////////////////
@@ -305,16 +269,10 @@ protected:
     ///////////////////////////////////////////////////////
 public:
     // interview related functions
-    virtual QModelIndex getCurrentIndex()                 {
-        return QModelIndex();
-    }
-    virtual bool        isSelected(const QModelIndex &) {
-        return false;
-    }
-    virtual bool        ensureVisibilityAfterSelect()     {
-        return true;
-    }
-    virtual void        selectRegion(KrViewItem *, KrViewItem *, bool) = 0;
+    virtual QModelIndex getCurrentIndex() = 0;
+    virtual bool isSelected(const QModelIndex &) = 0;
+    virtual bool ensureVisibilityAfterSelect() = 0;
+    virtual void selectRegion(KrViewItem *, KrViewItem *, bool) = 0;
 
     virtual uint numSelected() const = 0;
     virtual QList<QUrl> selectedUrls() = 0;
@@ -326,9 +284,11 @@ public:
     virtual KrViewItem *getCurrentKrViewItem() = 0;
     virtual KrViewItem *getKrViewItemAt(const QPoint &vp) = 0;
     virtual KrViewItem *findItemByName(const QString &name) = 0;
-    virtual KrViewItem *findItemByVfile(vfile *vf) = 0;
+    virtual KrViewItem *findItemByFileItem(FileItem *vf) = 0;
+    virtual KrViewItem *findItemByUrl(const QUrl &url) = 0;
     virtual QString getCurrentItem() const = 0;
-    virtual void setCurrentItem(const QString& name) = 0;
+    virtual void setCurrentItem(const QString &name,
+                                const QModelIndex &fallbackToIndex = QModelIndex()) = 0;
     virtual void setCurrentKrViewItem(KrViewItem *item) = 0;
     virtual void makeItemVisible(const KrViewItem *item) = 0;
     virtual bool isItemVisible(const KrViewItem *item) = 0;
@@ -337,96 +297,59 @@ public:
     virtual void refreshColors() = 0;
     virtual void redraw() = 0;
     virtual bool handleKeyEvent(QKeyEvent *e);
-    virtual void prepareForActive() {
-        _focused = true;
-    }
-    virtual void prepareForPassive() {
-        _focused = false;
-    }
-    virtual void renameCurrentItem(); // Rename current item. returns immediately
-    virtual int  itemsPerPage() {
-        return 0;
-    }
-    virtual void showContextMenu(const QPoint & point = QPoint(0,0)) = 0;
+    virtual void prepareForActive() = 0;
+    virtual void prepareForPassive() = 0;
+    virtual void renameCurrentItem() = 0; // Rename current item. returns immediately
+    virtual int itemsPerPage() = 0;
+    virtual void showContextMenu(const QPoint &point = QPoint(0, 0)) = 0;
 
 protected:
-    virtual KrViewItem *preAddItem(vfile *vf) = 0;
+    virtual KrViewItem *preAddItem(FileItem *fileitem) = 0;
     virtual void preDelItem(KrViewItem *item) = 0;
-    virtual void preUpdateItem(vfile *vf) = 0;
+    virtual void preUpdateItem(FileItem *fileitem) = 0;
     virtual void copySettingsFrom(KrView *other) = 0;
-    virtual void populate(const QList<vfile*> &vfiles, vfile *dummy) = 0;
-    virtual void intSetSelected(const vfile* vf, bool select) = 0;
-    virtual void updatePreviews();
+    virtual void populate(const QList<FileItem *> &fileItems, FileItem *dummy) = 0;
+    virtual void intSetSelected(const FileItem *fileitem, bool select) = 0;
     virtual void clear();
 
-    virtual void addItem(vfile *vf);
-    virtual void updateItem(vfile *vf);
-    virtual void delItem(const QString &name);
+    void addItem(FileItem *fileitem);
+    void updateItem(FileItem *fileitem);
+    void delItem(const QString &name);
 
 public:
     //////////////////////////////////////////////////////
     // the following functions are already implemented, //
     // and normally - should NOT be re-implemented.     //
     //////////////////////////////////////////////////////
-    virtual uint numFiles() const {
-        return _count -_numDirs;
-    }
-    virtual uint numDirs() const {
-        return _numDirs;
-    }
-    virtual uint count() const {
-        return _count;
-    }
-    virtual void getSelectedItems(QStringList* names, bool ignoreJustFocused = false);
-    virtual void getItemsByMask(QString mask, QStringList* names, bool dirs = true, bool files = true);
-    virtual void getSelectedKrViewItems(KrViewItemList *items);
-    virtual void selectAllIncludingDirs() {
-        changeSelection(KRQuery("*"), true, true);
-    }
-    virtual void select(const KRQuery& filter = KRQuery("*")) {
-        changeSelection(filter, true);
-    }
-    virtual void unselect(const KRQuery& filter = KRQuery("*")) {
-        changeSelection(filter, false);
-    }
-    virtual void unselectAll() {
-        changeSelection(KRQuery("*"), false, true);
-    }
-    virtual void invertSelection();
-    virtual QString nameToMakeCurrent() const {
-        return _nameToMakeCurrent;
-    }
-    virtual void setNameToMakeCurrent(const QString name) {
-        _nameToMakeCurrent = name;
-    }
-    virtual QString nameToMakeCurrentIfAdded() const {
-        return _nameToMakeCurrentIfAdded;
-    }
-    virtual void setNameToMakeCurrentIfAdded(const QString name) {
-        _nameToMakeCurrentIfAdded = name;
-    }
-    virtual QString firstUnmarkedBelowCurrent();
-    virtual QString statistics();
-    virtual const KrViewProperties* properties() const {
-        return _properties;
-    }
-    virtual KrViewOperator* op() const {
-        return _operator;
-    }
-    virtual void showPreviews(bool show);
-    virtual bool previewsShown() {
-        return _previews != 0;
-    }
-    virtual void applySettingsToOthers();
+    uint numFiles() const { return _count - _numDirs; }
+    uint numDirs() const { return _numDirs; }
+    uint count() const { return _count; }
+    void getSelectedItems(QStringList *names, bool ignoreJustFocused = false);
+    void getItemsByMask(QString mask, QStringList *names, bool dirs = true, bool files = true);
+    void getSelectedKrViewItems(KrViewItemList *items);
+    void selectAllIncludingDirs() { changeSelection(KRQuery("*"), true, true); }
+    void select(const KRQuery &filter = KRQuery("*")) { changeSelection(filter, true); }
+    void unselect(const KRQuery &filter = KRQuery("*")) { changeSelection(filter, false); }
+    void unselectAll() { changeSelection(KRQuery("*"), false, true); }
+    void invertSelection();
+    QString nameToMakeCurrent() const { return _nameToMakeCurrent; }
+    void setNameToMakeCurrent(const QString name) { _nameToMakeCurrent = name; }
+    QString firstUnmarkedBelowCurrent();
+    QString statistics();
+    const KrViewProperties *properties() const { return _properties; }
+    KrViewOperator *op() const { return _operator; }
+    void showPreviews(bool show);
+    bool previewsShown() { return _previews != 0; }
+    void applySettingsToOthers();
 
-    virtual void setFiles(VfileContainer *files);
-    virtual void refresh();
+    void setFiles(DirListerInterface *files);
+    void refresh();
 
-    bool changeSelection(const KRQuery& filter, bool select);
-    bool changeSelection(const KRQuery& filter, bool select, bool includeDirs, bool makeVisible = false);
-    bool isFiltered(vfile *vf);
-    void enableUpdateDefaultSettings(bool enable);
-    void setSelected(const vfile* vf, bool select);
+    bool changeSelection(const KRQuery &filter, bool select);
+    bool changeSelection(const KRQuery &filter, bool select, bool includeDirs,
+                         bool makeVisible = false);
+    bool isFiltered(FileItem *fileitem);
+    void setSelected(const FileItem *fileitem, bool select);
 
     /////////////////////////////////////////////////////////////
     // the following functions have a default and minimalistic //
@@ -435,45 +358,34 @@ public:
     virtual void setSortMode(KrViewProperties::ColumnType sortColumn, bool descending) {
         sortModeUpdated(sortColumn, descending);
     }
-    virtual const KRQuery& filterMask() const {
-        return _properties->filterMask;
-    }
-    virtual KrViewProperties::FilterSpec filter() const {
-        return _properties->filter;
-    }
-    virtual void setFilter(KrViewProperties::FilterSpec filter);
-    virtual void setFilter(KrViewProperties::FilterSpec filter, FilterSettings customFilter, bool applyToDirs);
-    virtual void customSelection(bool select);
-    virtual int defaultFileIconSize();
+    const KRQuery &filterMask() const { return _properties->filterMask; }
+    KrViewProperties::FilterSpec filter() const { return _properties->filter; }
+    void setFilter(KrViewProperties::FilterSpec filter);
+    void setFilter(KrViewProperties::FilterSpec filter, FilterSettings customFilter,
+                   bool applyToDirs);
+    void customSelection(bool select);
+    int defaultFileIconSize();
     virtual void setFileIconSize(int size);
-    virtual void setDefaultFileIconSize() {
-        setFileIconSize(defaultFileIconSize());
-    }
-    virtual void zoomIn();
-    virtual void zoomOut();
+    void setDefaultFileIconSize() { setFileIconSize(defaultFileIconSize()); }
+    void zoomIn();
+    void zoomOut();
 
     // save this view's settings to be restored after restart
-    virtual void saveSettings(KConfigGroup grp,
-        KrViewProperties::PropertyType properties = KrViewProperties::AllProperties);
+    virtual void
+    saveSettings(KConfigGroup grp,
+                 KrViewProperties::PropertyType properties = KrViewProperties::AllProperties);
 
-    inline QWidget *widget() {
-        return _widget;
-    }
-    inline int fileIconSize() const {
-        return _fileIconSize;
-    }
-    inline bool isFocused() const {
-        return _focused;
-    }
+    inline QWidget *widget() { return _widget; }
+    inline int fileIconSize() const { return _fileIconSize; }
+    inline bool isFocused() const { return _focused; }
 
-    QPixmap getIcon(vfile *vf);
+    QPixmap getIcon(FileItem *fileitem);
 
-    void setMainWindow(QWidget *mainWindow) {
-        _mainWindow = mainWindow;
-    }
+    void setMainWindow(QWidget *mainWindow) { _mainWindow = mainWindow; }
 
     // save this view's settings as default for new views of this type
-    void saveDefaultSettings(KrViewProperties::PropertyType properties = KrViewProperties::AllProperties);
+    void saveDefaultSettings(
+        KrViewProperties::PropertyType properties = KrViewProperties::AllProperties);
     // restore the default settings for this view type
     void restoreDefaultSettings();
     // call this to restore this view's settings after restart
@@ -481,9 +393,7 @@ public:
 
     void saveSelection();
     void restoreSelection();
-    bool canRestoreSelection() {
-        return !_savedSelection.isEmpty();
-    }
+    bool canRestoreSelection() { return !_savedSelection.isEmpty(); }
     void clearSavedSelection();
 
     void markSameBaseName();
@@ -492,9 +402,10 @@ public:
     // todo: what about selection modes ???
     virtual ~KrView();
 
-    static QPixmap getIcon(vfile *vf, bool active, int size = 0);
-    static QPixmap processIcon(const QPixmap &icon, bool dim, const QColor & dimColor, int dimFactor, bool symlink);
-    static QString krPermissionString(const vfile * vf);
+    static QPixmap getIcon(FileItem *fileitem, bool active, int size = 0);
+    static QPixmap processIcon(const QPixmap &icon, bool dim, const QColor &dimColor, int dimFactor,
+                               bool symlink);
+    static QString krPermissionString(const FileItem *fileitem);
 
 protected:
     KrView(KrViewInstance &instance, KConfig *cfg);
@@ -502,34 +413,32 @@ protected:
     virtual void doRestoreSettings(KConfigGroup grp);
     virtual KIO::filesize_t calcSize() = 0;
     virtual KIO::filesize_t calcSelectedSize() = 0;
-    bool handleKeyEventInt(QKeyEvent *e);
     void sortModeUpdated(KrViewProperties::ColumnType sortColumn, bool descending);
+    inline void setWidget(QWidget *w) { _widget = w; }
+
+    KConfig *_config;
+    KrViewProperties *_properties;
+    KrViewOperator *_operator;
+    bool _focused;
+    int _fileIconSize;
+
+private:
+    void updatePreviews();
     void saveSortMode(KConfigGroup &group);
     void restoreSortMode(KConfigGroup &group);
-    inline void setWidget(QWidget *w) {
-        _widget = w;
-    }
 
     KrViewInstance &_instance;
-    VfileContainer *_files;
-    KConfig *_config;
+    DirListerInterface *_files;
     QWidget *_mainWindow;
     QWidget *_widget;
     QList<QUrl> _savedSelection;
     QString _nameToMakeCurrent;
-    QString _nameToMakeCurrentIfAdded;
-    KrViewProperties *_properties;
-    KrViewOperator *_operator;
-    bool _focused;
     KrPreviews *_previews;
-    int _fileIconSize;
     bool _updateDefaultSettings;
+    bool _ignoreSettingsChange;
     QRegExp _quickFilterMask;
-
-private:
     uint _count, _numDirs;
-    vfile *_dummyVfile;
+    FileItem *_dummyFileItem;
 };
 
-
 #endif /* KRVIEW_H */
