@@ -58,8 +58,6 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include <KI18n/KLocalizedString>
 #include <KIconThemes/KIconLoader>
 #include <KIO/DropJob>
-#include <KIOCore/KMountPoint>
-#include <KIOCore/KDiskFreeSpaceInfo>
 #include <KWidgetsAddons/KCursor>
 #include <KWidgetsAddons/KMessageBox>
 #include <KIOFileWidgets/KFilePlacesModel>
@@ -71,8 +69,9 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include "../kicons.h"
 #include "../krusaderview.h"
 #include "../krservices.h"
-#include "../VFS/krpermhandler.h"
-#include "../VFS/krarchandler.h"
+#include "../FileSystem/filesystem.h"
+#include "../FileSystem/krpermhandler.h"
+#include "../Archive/krarchandler.h"
 #include "../MountMan/kmountman.h"
 #include "../BookMan/krbookmarkbutton.h"
 #include "../Dialogs/krdialogs.h"
@@ -126,17 +125,16 @@ protected:
 //      The list panel constructor       //
 /////////////////////////////////////////////////////
 ListPanel::ListPanel(QWidget *parent, AbstractPanelManager *manager, KConfigGroup cfg) :
-        QWidget(parent), KrPanel(manager),
+        QWidget(parent), KrPanel(manager, this, new ListPanelFunc(this)),
         panelType(-1), colorMask(255), compareMode(false),
         previewJob(0), inlineRefreshJob(0), searchBar(0), cdRootButton(0), cdUpButton(0),
-        popupBtn(0), popup(0), vfsError(0), _locked(false)
+        popupBtn(0), popup(0), fileSystemError(0), _navigatorUrl(), _locked(false)
 {
     if(cfg.isValid())
         panelType = cfg.readEntry("Type", -1);
     if (panelType == -1)
         panelType = defaultPanelType();
-    gui = this;
-    func = new ListPanelFunc(this);
+
     _actions = krApp->listPanelActions();
 
     setAcceptDrops(true);
@@ -148,8 +146,8 @@ ListPanel::ListPanel(QWidget *parent, AbstractPanelManager *manager, KConfigGrou
     // media button
     mediaButton = new MediaButton(this);
     connect(mediaButton, SIGNAL(aboutToShow()), this, SLOT(slotFocusOnMe()));
-    connect(mediaButton, SIGNAL(openUrl(const QUrl&)), func, SLOT(openUrl(const QUrl&)));
-    connect(mediaButton, SIGNAL(newTab(const QUrl&)), SLOT(newTab(const QUrl&)));
+    connect(mediaButton, SIGNAL(openUrl(QUrl)), func, SLOT(openUrl(QUrl)));
+    connect(mediaButton, SIGNAL(newTab(QUrl)), SLOT(newTab(QUrl)));
     ADD_WIDGET(mediaButton);
 
     // status bar
@@ -181,7 +179,7 @@ ListPanel::ListPanel(QWidget *parent, AbstractPanelManager *manager, KConfigGrou
     // bookmarks button
     bookmarksButton = new KrBookmarkButton(this);
     connect(bookmarksButton, SIGNAL(aboutToShow()), this, SLOT(slotFocusOnMe()));
-    connect(bookmarksButton, SIGNAL(openUrl(const QUrl&)), func, SLOT(openUrl(const QUrl&)));
+    connect(bookmarksButton, SIGNAL(openUrl(QUrl)), func, SLOT(openUrl(QUrl)));
     bookmarksButton->setWhatsThis(i18n("Open menu with bookmarks. You can also add "
                                        "current location to the list, edit bookmarks "
                                        "or add subfolder to the list."));
@@ -197,10 +195,10 @@ ListPanel::ListPanel(QWidget *parent, AbstractPanelManager *manager, KConfigGrou
     urlNavigator->setUrlEditable(isNavigatorEditModeSet());
     urlNavigator->setShowFullPath(group.readEntry("Navigator Full Path", false));
     connect(urlNavigator, SIGNAL(returnPressed()), this, SLOT(slotFocusOnMe()));
-    connect(urlNavigator, SIGNAL(urlChanged(QUrl)), func, SLOT(navigatorUrlChanged(QUrl)));
-    connect(urlNavigator->editor()->lineEdit(), SIGNAL(editingFinished()), this, SLOT(resetNavigatorMode()));
+    connect(urlNavigator, &KUrlNavigator::urlChanged, this, &ListPanel::slotNavigatorUrlChanged);
+    connect(urlNavigator->editor()->lineEdit(), &QLineEdit::editingFinished, this, &ListPanel::resetNavigatorMode);
     connect(urlNavigator, SIGNAL(tabRequested(QUrl)), this, SLOT(newTab(QUrl)));
-    connect(urlNavigator, SIGNAL(urlsDropped(QUrl, QDropEvent*)), this, SLOT(handleDrop(QUrl, QDropEvent*)));
+    connect(urlNavigator, SIGNAL(urlsDropped(QUrl,QDropEvent*)), this, SLOT(handleDrop(QUrl,QDropEvent*)));
     ADD_WIDGET(urlNavigator);
 
     // toolbar
@@ -210,10 +208,10 @@ ListPanel::ListPanel(QWidget *parent, AbstractPanelManager *manager, KConfigGrou
     toolbarLayout->setSpacing(0);
     ADD_WIDGET(toolbar);
 
-    vfsError = new KrErrorDisplay(this);
-    vfsError->setWordWrap(true);
-    vfsError->hide();
-    ADD_WIDGET(vfsError);
+    fileSystemError = new KrErrorDisplay(this);
+    fileSystemError->setWordWrap(true);
+    fileSystemError->hide();
+    ADD_WIDGET(fileSystemError);
 
     // client area
     clientArea = new QWidget(this);
@@ -338,7 +336,7 @@ ListPanel::ListPanel(QWidget *parent, AbstractPanelManager *manager, KConfigGrou
         h->addWidget(bookmarksButton);
         v->addLayout(h);
 
-        v->addWidget(vfsError);
+        v->addWidget(fileSystemError);
         v->addWidget(clientArea);
 
         h = new QHBoxLayout;
@@ -415,23 +413,22 @@ void ListPanel::createView()
 
     view->widget()->installEventFilter(this);
 
-    connect(view->op(), SIGNAL(calcSpace(KrViewItem*)), func, SLOT(calcSpace(KrViewItem*)));
     connect(view->op(), SIGNAL(goHome()), func, SLOT(home()));
     connect(view->op(), SIGNAL(dirUp()), func, SLOT(dirUp()));
-    connect(view->op(), SIGNAL(deleteFiles(bool)), func, SLOT(deleteFiles(bool)));
-    connect(view->op(), SIGNAL(middleButtonClicked(KrViewItem *)), SLOT(newTab(KrViewItem *)));
-    connect(view->op(), SIGNAL(currentChanged(KrViewItem *)), SLOT(updatePopupPanel(KrViewItem*)));
-    connect(view->op(), SIGNAL(renameItem(const QString &, const QString &)),
-            func, SLOT(rename(const QString &, const QString &)));
-    connect(view->op(), SIGNAL(executed(const QString&)), func, SLOT(execute(const QString&)));
-    connect(view->op(), SIGNAL(goInside(const QString&)), func, SLOT(goInside(const QString&)));
+    connect(view->op(), &KrViewOperator::defaultDeleteFiles, func, &ListPanelFunc::defaultDeleteFiles);
+    connect(view->op(), SIGNAL(middleButtonClicked(KrViewItem*)), SLOT(newTab(KrViewItem*)));
+    connect(view->op(), SIGNAL(currentChanged(KrViewItem*)), SLOT(slotCurrentChanged(KrViewItem*)));
+    connect(view->op(), SIGNAL(renameItem(QString,QString)),
+            func, SLOT(rename(QString,QString)));
+    connect(view->op(), SIGNAL(executed(QString)), func, SLOT(execute(QString)));
+    connect(view->op(), SIGNAL(goInside(QString)), func, SLOT(goInside(QString)));
     connect(view->op(), SIGNAL(needFocus()), this, SLOT(slotFocusOnMe()));
     connect(view->op(), SIGNAL(selectionChanged()), this, SLOT(slotUpdateTotals()));
-    connect(view->op(), SIGNAL(itemDescription(QString&)), krApp, SLOT(statusBarUpdate(QString&)));
-    connect(view->op(), SIGNAL(contextMenu(const QPoint &)), this, SLOT(popRightClickMenu(const QPoint &)));
-    connect(view->op(), SIGNAL(emptyContextMenu(const QPoint &)),
-            this, SLOT(popEmptyRightClickMenu(const QPoint &)));
-    connect(view->op(), SIGNAL(letsDrag(QStringList, QPixmap)), this, SLOT(startDragging(QStringList, QPixmap)));
+    connect(view->op(), SIGNAL(itemDescription(QString)), krApp, SLOT(statusBarUpdate(QString)));
+    connect(view->op(), SIGNAL(contextMenu(QPoint)), this, SLOT(popRightClickMenu(QPoint)));
+    connect(view->op(), SIGNAL(emptyContextMenu(QPoint)),
+            this, SLOT(popEmptyRightClickMenu(QPoint)));
+    connect(view->op(), SIGNAL(letsDrag(QStringList,QPixmap)), this, SLOT(startDragging(QStringList,QPixmap)));
     connect(view->op(), &KrViewOperator::gotDrop,
             this, [this](QDropEvent *event) {handleDrop(event, true); });
     connect(view->op(), SIGNAL(previewJobStarted(KJob*)), this, SLOT(slotPreviewJobStarted(KJob*)));
@@ -535,8 +532,8 @@ void ListPanel::togglePanelPopup()
         QSizePolicy sizePolicy = popup->sizePolicy();
         sizePolicy.setVerticalPolicy(QSizePolicy::Ignored);
         popup->setSizePolicy(sizePolicy);
-        connect(this, SIGNAL(pathChanged(const QUrl&)), popup, SLOT(onPanelPathChange(const QUrl&)));
-        connect(popup, SIGNAL(selection(const QUrl&)), SLOTS, SLOT(refresh(const QUrl&)));
+        connect(this, SIGNAL(pathChanged(QUrl)), popup, SLOT(onPanelPathChange(QUrl)));
+        connect(popup, SIGNAL(selection(QUrl)), SLOTS, SLOT(refresh(QUrl)));
         connect(popup, SIGNAL(hideMe()), this, SLOT(togglePanelPopup()));
     }
 
@@ -569,9 +566,9 @@ void ListPanel::togglePanelPopup()
     }
 }
 
-QString ListPanel::realPath() const
+QString ListPanel::lastLocalPath() const
 {
-    return _realPath.path();
+    return _lastLocalPath;
 }
 
 void ListPanel::setButtons()
@@ -633,15 +630,15 @@ void ListPanel::compareDirs(bool otherPanelToo)
 
         bool isSingle = (otherItem == 0), isDifferent = false, isNewer = false;
 
-        if (func->getVFile(item)->vfile_isDir() && !selectDirs) {
+        if (func->getFileItem(item)->isDir() && !selectDirs) {
             item->setSelected(false);
             continue;
         }
 
         if (otherItem) {
-            if (!func->getVFile(item)->vfile_isDir())
-                isDifferent = ITEM2VFILE(otherPanel(), otherItem)->vfile_getSize() != func->getVFile(item)->vfile_getSize();
-            isNewer = func->getVFile(item)->vfile_getTime_t() > ITEM2VFILE(otherPanel(), otherItem)->vfile_getTime_t();
+            if (!func->getFileItem(item)->isDir())
+                isDifferent = otherPanel()->func->getFileItem(otherItem)->getSize() != func->getFileItem(item)->getSize();
+            isNewer = func->getFileItem(item)->getTime_t() > otherPanel()->func->getFileItem(otherItem)->getTime_t();
         }
 
         switch (compareMode) {
@@ -688,13 +685,13 @@ void ListPanel::slotFocusOnMe(bool focus)
         emit activate();
         _actions->activePanelChanged();
         func->refreshActions();
-        updatePopupPanel(view->getCurrentKrViewItem());
+        slotCurrentChanged(view->getCurrentKrViewItem());
         view->prepareForActive();
         otherPanel()->gui->slotFocusOnMe(false);
     } else {
         // in case a new url was entered but not refreshed to,
         // reset url navigator to the current url
-        urlNavigator->setLocationUrl(virtualPath());
+        setNavigatorUrl(virtualPath());
         view->prepareForPassive();
     }
 
@@ -707,123 +704,78 @@ void ListPanel::slotFocusOnMe(bool focus)
 
 // this is used to start the panel
 //////////////////////////////////////////////////////////////////
-void ListPanel::start(QUrl url, bool immediate)
+void ListPanel::start(const QUrl &url)
 {
-    QUrl virt(url);
+    QUrl startUrl(url);
 
-    if (!virt.isValid())
-        virt = QUrl::fromLocalFile(ROOT_DIR);
-    if (virt.isLocalFile())
-        _realPath = virt;
-    else
-        _realPath = QUrl::fromLocalFile(ROOT_DIR);
+    if (!startUrl.isValid())
+        startUrl = QUrl::fromLocalFile(ROOT_DIR);
 
-    if (immediate)
-        func->immediateOpenUrl(virt, true);
-    else
-        func->openUrl(virt);
+    _lastLocalPath = startUrl.isLocalFile() ? startUrl.path() : ROOT_DIR;
 
-    setJumpBack(virt);
+
+    func->openUrl(startUrl);
+
+    setJumpBack(startUrl);
 }
 
-void ListPanel::slotStartUpdate()
+void ListPanel::slotStartUpdate(bool directoryChange)
 {
     if (inlineRefreshJob)
         inlineRefreshListResult(0);
 
-    if (this == ACTIVE_PANEL) {
-        slotFocusOnMe();
-    }
-
     setCursor(Qt::BusyCursor);
 
-    if (func->files()->vfs_getType() == vfs::VFS_NORMAL)
-        _realPath = virtualPath();
-    urlNavigator->setLocationUrl(virtualPath());
-    emit pathChanged(this);
-    emit pathChanged(virtualPath());
+    const QUrl currentUrl = virtualPath();
+    if (directoryChange) {
+
+        if (this == ACTIVE_PANEL) {
+            slotFocusOnMe();
+        }
+
+        if (currentUrl.isLocalFile())
+            _lastLocalPath = currentUrl.path();
+
+        setNavigatorUrl(currentUrl);
+
+        emit pathChanged(currentUrl);
+
+        krApp->popularUrls()->addUrl(currentUrl);
+
+        searchBar->hideBar();
+    }
 
-    slotGetStats(virtualPath());
     if (compareMode)
         otherPanel()->view->refresh();
 
     // return cursor to normal arrow
     setCursor(Qt::ArrowCursor);
-    slotUpdateTotals();
-    krApp->popularUrls()->addUrl(virtualPath());
 
-    searchBar->hideBar();
+    slotUpdateTotals();
 }
 
-void ListPanel::slotGetStats(const QUrl &url)
+void ListPanel::updateFilesystemStats(const QString &metaInfo, const QString &fsType,
+                                      KIO::filesize_t total, KIO::filesize_t free)
 {
-    mediaButton->mountPointChanged(QString());
-    freeSpace->setText(QString());
+    QString statusText, mountPoint, freeSpaceText;
 
-    if (!KConfigGroup(krConfig, "Look&Feel").readEntry("ShowSpaceInformation", true)) {
-        if(func->files()->metaInformation().isEmpty())
-            status->setText(i18n("Space information disabled"));
-        else
-            status->setText(func->files()->metaInformation());
-        return ;
+    if (!metaInfo.isEmpty()) {
+        statusText = metaInfo;
+        mountPoint = freeSpaceText = "";
+    } else {
+        const int perc = total == 0 ? 0 : (int)(((float)free / (float)total) * 100.0);
+        mountPoint = func->files()->mountPoint();
+        statusText = i18nc("%1=free space,%2=total space,%3=percentage of usage, "
+                           "%4=mountpoint,%5=filesystem type",
+                           "%1 free out of %2 (%3%) on %4 [(%5)]", KIO::convertSize(free),
+                           KIO::convertSize(total), perc, mountPoint, fsType);
+
+        freeSpaceText = "    " + i18n("%1 free", KIO::convertSize(free));
     }
 
-    if (!url.isLocalFile()) {
-        if(func->files()->metaInformation().isEmpty())
-            status->setText(i18n("No space information on non-local filesystems"));
-        else
-            status->setText(func->files()->metaInformation());
-        return ;
-    }
-
-    // check for special filesystems;
-    QString path = url.path(); // must be local url
-    if (path.left(4) == "/dev") {
-        status->setText(i18n("No space information on [dev]"));
-        return;
-    }
-#ifdef BSD
-    if (path.left(5) == "/procfs") {     // /procfs is a special case - no volume information
-        status->setText(i18n("No space information on [procfs]"));
-        return;
-    }
-#else
-    if (path.left(5) == "/proc") {     // /proc is a special case - no volume information
-        status->setText(i18n("No space information on [proc]"));
-        return;
-    }
-#endif
-
-    KDiskFreeSpaceInfo info = KDiskFreeSpaceInfo::freeSpaceInfo(path);
-    if(!info.isValid()) {
-        status->setText(i18n("Space information unavailable"));
-        return;
-    }
-    int perc = 0;
-    if (info.size() != 0) { // make sure that if totalsize==0, then perc=0
-        perc = (int)(((float)info.available() / (float)info.size()) * 100.0);
-    }
-    // mount point information - find it in the list first
-    KMountPoint::List lst = KMountPoint::currentMountPoints();
-    QString fstype = i18nc("Unknown file system type", "unknown");
-    for (KMountPoint::List::iterator it = lst.begin(); it != lst.end(); ++it) {
-        if ((*it)->mountPoint() == info.mountPoint()) {
-            fstype = (*it)->mountType();
-            break;
-        }
-    }
-
-    QString stats = i18nc("%1=free space,%2=total space,%3=percentage of usage, "
-                          "%4=mountpoint,%5=filesystem type",
-                          "%1 free out of %2 (%3%) on %4 [(%5)]",
-                          KIO::convertSize(info.available()),
-                          KIO::convertSize(info.size()), perc,
-                          info.mountPoint(), fstype);
-
-    status->setText(stats);
-
-    freeSpace->setText("    " + i18n("%1 free", KIO::convertSize(info.available())));
-    mediaButton->mountPointChanged(info.mountPoint());
+    status->setText(statusText);
+    freeSpace->setText(freeSpaceText);
+    mediaButton->updateIcon(mountPoint);
 }
 
 void ListPanel::handleDrop(QDropEvent *event, bool onView)
@@ -840,11 +792,11 @@ void ListPanel::handleDrop(QDropEvent *event, bool onView)
     const bool dragFromThisPanel = event->source() == this;
     const KrViewItem *item = onView ? view->getKrViewItemAt(event->pos()) : 0;
     if (item) {
-        const vfile *file = item->getVfile();
-        if (file && !file->vfile_isDir() && dragFromThisPanel) {
+        const FileItem *file = item->getFileItem();
+        if (file && !file->isDir() && dragFromThisPanel) {
             event->ignore(); // dragging on files in same panel, ignore
             return ;
-        } else if (!file || file->vfile_isDir()) { // item is ".." dummy or a directory
+        } else if (!file || file->isDir()) { // item is ".." dummy or a directory
             destinationDir = item->name();
         }
     } else if (dragFromThisPanel) {
@@ -855,7 +807,7 @@ void ListPanel::handleDrop(QDropEvent *event, bool onView)
     QUrl destination = QUrl(virtualPath());
     destination.setPath(destination.path() + '/' + destinationDir);
 
-    func->files()->vfs_drop(destination, event);
+    func->files()->dropFiles(destination, event);
 
     if(KConfigGroup(krConfig, "Look&Feel").readEntry("UnselectBeforeOperation",
                                                      _UnselectBeforeOperation)) {
@@ -867,21 +819,7 @@ void ListPanel::handleDrop(QDropEvent *event, bool onView)
 
 void ListPanel::handleDrop(const QUrl &destination, QDropEvent *event)
 {
-    func->files()->vfs_drop(destination, event);
-}
-
-void ListPanel::slotJobResult(KJob *job)
-{
-    func->refresh(); // see new files if not on local filesystem
-    if (job->error()) {
-        slotVfsError(job->errorString());
-    }
-}
-
-void ListPanel::vfs_refresh(KJob* /*job*/)
-{
-    if (func)
-        func->refresh();
+    func->files()->dropFiles(destination, event);
 }
 
 void ListPanel::startDragging(QStringList names, QPixmap px)
@@ -890,7 +828,7 @@ void ListPanel::startDragging(QStringList names, QPixmap px)
         return;
     }
 
-    QList<QUrl> urls = func->files()->vfs_getFiles(names);
+    QList<QUrl> urls = func->files()->getUrls(names);
 
     QDrag *drag = new QDrag(this);
     QMimeData *mimeData = new QMimeData;
@@ -898,7 +836,7 @@ void ListPanel::startDragging(QStringList names, QPixmap px)
     mimeData->setUrls(urls);
     drag->setMimeData(mimeData);
 
-    drag->start();
+    drag->start(Qt::MoveAction | Qt::CopyAction | Qt::LinkAction);
 }
 
 // pops a right-click menu for items
@@ -935,11 +873,11 @@ void ListPanel::keyPressEvent(QKeyEvent *e)
     case Qt::Key_Return :
         if (e->modifiers() & Qt::ControlModifier) {
             if (e->modifiers() & Qt::AltModifier) {
-                vfile *vf = func->files()->vfs_search(view->getCurrentKrViewItem()->name());
-                if (vf && vf->vfile_isDir())
-                    newTab(vf->vfile_getUrl(), true);
+                FileItem *fileitem = func->files()->getFileItem(view->getCurrentKrViewItem()->name());
+                if (fileitem && fileitem->isDir())
+                    newTab(fileitem->getUrl(), true);
             } else {
-                SLOTS->insertFileName((e->modifiers() & Qt::ShiftModifier) != 0);
+                SLOTS->insertFileName((e->modifiers()&Qt::ShiftModifier)!=0);
             }
         } else e->ignore();
         break;
@@ -953,23 +891,25 @@ void ListPanel::keyPressEvent(QKeyEvent *e)
                 KrViewItem *it = view->getCurrentKrViewItem();
 
                 if (it->name() == "..") {
-                    newPath = KIO::upUrl(func->files()->vfs_getOrigin());
+                    newPath = KIO::upUrl(virtualPath());
                 } else {
-                    vfile *v = func->getVFile(it);
+                    FileItem *v = func->getFileItem(it);
                     // If it's a directory different from ".."
-                    if (v && v->vfile_isDir() && v->vfile_getName() != "..") {
-                        newPath = v->vfile_getUrl();
+                    if (v && v->isDir() && v->getName() != "..") {
+                        newPath = v->getUrl();
                     } else {
                         // If it's a supported compressed file
-                        if (v && KRarcHandler::arcSupported(v->vfile_getMime()))   {
-                            newPath = func->browsableArchivePath(v->vfile_getUrl().fileName());
+                        if (v && KRarcHandler::arcSupported(v->getMime()))   {
+                            newPath = func->browsableArchivePath(v->getUrl().fileName());
                         } else {
-                            newPath = func->files()->vfs_getOrigin();
+                            newPath = virtualPath();
                         }
                     }
                 }
                 otherPanel()->func->openUrl(newPath);
-            } else func->openUrl(otherPanel()->func->files() ->vfs_getOrigin());
+            } else {
+                func->openUrl(otherPanel()->virtualPath());
+            }
             return ;
         } else
             e->ignore();
@@ -1011,41 +951,37 @@ void ListPanel::keyPressEvent(QKeyEvent *e)
 
 void ListPanel::showEvent(QShowEvent *e)
 {
-    panelActive();
+    panelVisible();
     QWidget::showEvent(e);
 }
 
 void ListPanel::hideEvent(QHideEvent *e)
 {
-    panelInactive();
+    panelHidden();
     QWidget::hideEvent(e);
 }
 
-void ListPanel::panelActive()
+void ListPanel::panelVisible()
 {
-    // don't refresh when not active (ie: hidden, application isn't focused ...)
-//     if (!
-         func->files()->vfs_enableRefresh(true)
-//        )
-//         func->popErronousUrl()
-                ;
+    func->setPaused(false);
 }
 
-void ListPanel::panelInactive()
+void ListPanel::panelHidden()
 {
-    func->files()->vfs_enableRefresh(false);
+    func->setPaused(true);
 }
 
 void ListPanel::slotPreviewJobStarted(KJob *job)
 {
     previewJob = job;
+    connect(job, SIGNAL(percent(KJob*,ulong)), SLOT(slotPreviewJobPercent(KJob*,ulong)));
+    connect(job, &KJob::result, this, &ListPanel::slotPreviewJobResult);
+    inlineRefreshCancelButton->setMaximumHeight(popupBtn->height());
+    inlineRefreshCancelButton->show();
     previewProgress->setValue(0);
     previewProgress->setFormat(i18n("loading previews: %p%"));
-    previewProgress->show();
-    inlineRefreshCancelButton->show();
     previewProgress->setMaximumHeight(inlineRefreshCancelButton->height());
-    connect(job, SIGNAL(percent(KJob*, unsigned long)), SLOT(slotPreviewJobPercent(KJob*, unsigned long)));
-    connect(job, SIGNAL(result(KJob*)), SLOT(slotPreviewJobResult(KJob*)));
+    previewProgress->show();
 }
 
 void ListPanel::slotPreviewJobPercent(KJob* /*job*/, unsigned long percent)
@@ -1078,10 +1014,10 @@ void ListPanel::slotJobStarted(KIO::Job* job)
     syncBrowseButton->setEnabled(false);
 
     // connect to the job interface to provide in-panel refresh notification
-    connect(job, SIGNAL(infoMessage(KJob*, const QString &)),
-            SLOT(inlineRefreshInfoMessage(KJob*, const QString &)));
-    connect(job, SIGNAL(percent(KJob*, unsigned long)),
-            SLOT(inlineRefreshPercent(KJob*, unsigned long)));
+    connect(job, SIGNAL(infoMessage(KJob*,QString)),
+            SLOT(inlineRefreshInfoMessage(KJob*,QString)));
+    connect(job, SIGNAL(percent(KJob*,ulong)),
+            SLOT(inlineRefreshPercent(KJob*,ulong)));
     connect(job, SIGNAL(result(KJob*)),
             this, SLOT(inlineRefreshListResult(KJob*)));
 
@@ -1105,6 +1041,12 @@ void ListPanel::inlineRefreshCancel()
     }
 }
 
+void ListPanel::setNavigatorUrl(const QUrl &url)
+{
+    _navigatorUrl = url;
+   urlNavigator->setLocationUrl(url);
+}
+
 void ListPanel::inlineRefreshPercent(KJob*, unsigned long perc)
 {
     QString msg = i18n(">> Reading: %1 % complete...", perc);
@@ -1149,11 +1091,11 @@ void ListPanel::setJumpBack(QUrl url)
     _jumpBackURL = url;
 }
 
-void ListPanel::slotVfsError(QString msg)
+void ListPanel::slotFilesystemError(QString msg)
 {
     refreshColors();
-    vfsError->setText(i18n("Error: %1", msg));
-    vfsError->show();
+    fileSystemError->setText(i18n("Error: %1", msg));
+    fileSystemError->show();
 }
 
 void ListPanel::showButtonMenu(QToolButton *b)
@@ -1241,14 +1183,12 @@ void ListPanel::restoreSettings(KConfigGroup cfg)
     setProperties(cfg.readEntry("Properties", 0));
     view->restoreSettings(KConfigGroup(&cfg, "View"));
 
-    func->files()->vfs_enableRefresh(true);
+    _lastLocalPath = ROOT_DIR;
 
-    _realPath = QUrl::fromLocalFile(ROOT_DIR);
-
-    if(func->history->restore(KConfigGroup(&cfg, "History")))
+    if(func->history->restore(KConfigGroup(&cfg, "History"))) {
         func->refresh();
-    else {
-        QUrl url(cfg.readEntry("Url", ROOT_DIR));
+    } else {
+        QUrl url(cfg.readEntry("Url", "invalid"));
         if (!url.isValid())
             url = QUrl::fromLocalFile(ROOT_DIR);
         func->openUrl(url);
@@ -1265,9 +1205,13 @@ void ListPanel::restoreSettings(KConfigGroup cfg)
     }
 }
 
-void ListPanel::updatePopupPanel(KrViewItem *item)
+void ListPanel::slotCurrentChanged(KrViewItem *item)
 {
-    // which panel to display on?
+    // update status bar
+    if (item)
+        krApp->statusBarUpdate(item->description());
+
+    // update popup panel; which panel to display on?
     PanelPopup *p;
     if(popup && !popup->isHidden())
         p = popup;
@@ -1276,7 +1220,7 @@ void ListPanel::updatePopupPanel(KrViewItem *item)
     else
         return;
 
-    p->update(item ? func->files()->vfs_search(item->name()) : 0);
+    p->update(item ? func->files()->getFileItem(item->name()) : 0);
 }
 
 void ListPanel::otherPanelChanged()
@@ -1311,7 +1255,7 @@ void ListPanel::newTab(KrViewItem *it)
         return;
     else if (it->name() == "..") {
         newTab(KIO::upUrl(virtualPath()), true);
-    } else if (ITEM2VFILE(this, it)->vfile_isDir()) {
+    } else if (func->getFileItem(it)->isDir()) {
         QUrl url = virtualPath();
         url = url.adjusted(QUrl::StripTrailingSlash);
         url.setPath(url.path() + '/' + (it->name()));
@@ -1319,6 +1263,18 @@ void ListPanel::newTab(KrViewItem *it)
     }
 }
 
+void ListPanel::slotNavigatorUrlChanged(const QUrl &url)
+{
+    if (url == _navigatorUrl)
+        return; // this is the URL we just set ourself
+
+    if (!isNavigatorEditModeSet()) {
+        urlNavigator->setUrlEditable(false);
+    }
+
+    func->openUrl(KrServices::escapeFileUrl(url), QString(), true);
+}
+
 void ListPanel::resetNavigatorMode()
 {
     if (isNavigatorEditModeSet())
