@@ -27,7 +27,7 @@
 #include "../Panel/krview.h"
 #include "../Search/krsearchdialog.h"
 #include "../GUI/profilemanager.h"
-#include "../VFS/preservingcopyjob.h"
+#include "../FileSystem/filesystemprovider.h"
 #include "../KViewer/krviewer.h"
 #include "../krservices.h"
 
@@ -94,8 +94,8 @@ QStringList exp_placeholder::fileList(const KrPanel* const panel, const QString&
         return QStringList();
     }
     if (!omitPath) {    // add the current path
-        // translate to urls using vfs
-        QList<QUrl> list = panel->func->files()->vfs_getFiles(items);
+        // translate to urls using filesystem
+        QList<QUrl> list = panel->func->files()->getUrls(items);
         items.clear();
         // parse everything to a single qstring
         foreach(const QUrl &url, list) {
@@ -270,7 +270,11 @@ QString separateAndQuote(QStringList list, const QString& separator, const bool
 {
     if (quote)
         transform(list.begin(), list.end(), list.begin(), bashquote);
-    return list.join(separator);
+
+    // QLineEdit::text() always escapes special characters, revert this for newline and tab
+    QString decodedSeparator = separator;
+    decodedSeparator.replace("\\n", "\n").replace("\\t", "\t");
+    return list.join(decodedSeparator);
 }
 /////////////////////////////////////////////////////////////////////////////////////////////////
 /////////////////////////////////// expander classes ////////////////////////////////////
@@ -291,9 +295,9 @@ TagString exp_Path::expFunc(const KrPanel* panel, const QStringList& parameter,
     QString result;
 
     if (useUrl)
-        result = panel->func->files()->vfs_getOrigin().url() + '/';
+        result = panel->func->files()->currentDirectory().url() + '/';
     else
-        result = panel->func->files()->vfs_getOrigin().path() + '/';
+        result = panel->func->files()->currentDirectory().path() + '/';
 
     if (parameter.count() > 0 && parameter[0].toLower() == "no")    // don't escape spaces
         return TagString(result);
@@ -363,7 +367,7 @@ TagString exp_Current::expFunc(const KrPanel* panel, const QStringList& paramete
     if (parameter.count() > 0 && parameter[0].toLower() == "yes")    // omit the current path
         result = item;
     else {
-        QUrl url = panel->func->files()->vfs_getFile(item);
+        QUrl url = panel->func->files()->getUrl(item);
         if (useUrl)
             result = url.url();
         else
@@ -530,7 +534,7 @@ exp_Search::exp_Search() {
    _needPanel = true;
 
    addParameter( new exp_parameter( i18n("please choose the setting"), "__searchprofile", true ) );
-   addParameter( new exp_parameter( i18n("open the search in a new tab"), "__yes", false ) );  //TODO: add this also to panel-dependent as soon as vfs support the display of search-results
+   addParameter( new exp_parameter( i18n("open the search in a new tab"), "__yes", false ) );  //TODO: add this also to panel-dependent as soon as filesystem support the display of search-results
 }
 */
 
@@ -636,7 +640,7 @@ TagString exp_Copy::expFunc(const KrPanel*, const TagStringList& parameter, cons
         return QString();
     }
 
-    PreservingCopyJob::createCopyJob(PM_DEFAULT, src, dest, KIO::CopyJob::Copy, false, true);
+    FileSystemProvider::instance().startCopyFiles(src, dest);
 
     return QString();  // this doesn't return everything, that's normal!
 }
@@ -674,7 +678,7 @@ TagString exp_Move::expFunc(const KrPanel*, const TagStringList& parameter, cons
         return QString();
     }
 
-    PreservingCopyJob::createCopyJob(PM_DEFAULT, src, dest, KIO::CopyJob::Move, false, true);
+    FileSystemProvider::instance().startCopyFiles(src, dest, KIO::CopyJob::Move);
 
     return QString();  // this doesn't return anything, that's normal!
 }
