@@ -177,7 +177,7 @@ void KrActionProcDlg::slotSaveAs()
         answer = KMessageBox::warningYesNoCancel(this,  //parent
                  i18n("This file already exists.\nDo you want to overwrite it or append the output?"), //text
                  i18n("Overwrite or append?"), //caption
-                 KGuiItem(i18n("Overwrite")),   //label for Yes-Button
+                 KStandardGuiItem::overwrite(),   //label for Yes-Button
                  KGuiItem(i18n("Append"))   //label for No-Button
                                                 );
     if (answer == KMessageBox::Cancel)
@@ -241,6 +241,15 @@ void KrActionProc::start(QStringList cmdLineList)
     if (! _action->startpath().isEmpty())
         workingDir = _action->startpath();
 
+    if (!_action->user().isEmpty()) {
+        if (!KrServices::isExecutable(KDESU_PATH)) {
+            KMessageBox::sorry(0,
+                i18n("Cannot run user action, %1 not found or not executable. "
+                     "Please verify that kde-cli-tools are installed.", QString(KDESU_PATH)));
+            return;
+        }
+    }
+
     if (_action->execType() == KrAction::RunInTE
             && (! MAIN_VIEW->terminalDock()->initialise())) {
         KMessageBox::sorry(0, i18n("Embedded terminal emulator does not work, using output collection instead."));
@@ -262,7 +271,8 @@ void KrActionProc::start(QStringList cmdLineList)
         && MAIN_VIEW->terminalDock()->isInitialised()) {  //send the commandline contents to the terminal emulator
             if (!_action->user().isEmpty()) {
                 // "-t" is necessary that kdesu displays the terminal-output of the command
-                cmd = "kdesu -t -u " + _action->user() + " -c " + KrServices::quote(cmd);
+                cmd = KrServices::quote(KDESU_PATH) +
+                      " -t -u " + _action->user() + " -c " + KrServices::quote(cmd);
             }
             MAIN_VIEW->terminalDock()->sendInput(cmd + '\n');
             deleteLater();
@@ -271,8 +281,8 @@ void KrActionProc::start(QStringList cmdLineList)
         _proc = new KProcess(this);
         _proc->clearProgram(); // this clears the arglist too
         _proc->setWorkingDirectory(workingDir);
-        connect(_proc, SIGNAL(finished(int, QProcess::ExitStatus)),
-                this, SLOT(processExited(int, QProcess::ExitStatus)));
+        connect(_proc, SIGNAL(finished(int,QProcess::ExitStatus)),
+                this, SLOT(processExited(int,QProcess::ExitStatus)));
 
         if (_action->execType() == KrAction::Normal || _action->execType() == KrAction::Terminal) { // not collect output
             if (_action->execType() == KrAction::Terminal) { // run in terminal
@@ -295,7 +305,8 @@ void KrActionProc::start(QStringList cmdLineList)
                 cmd = KrServices::quote(termArgs).join(" ");
             }
             if (!_action->user().isEmpty()) {
-                cmd = "kdesu -u " + _action->user() + " -c " + KrServices::quote(cmd);
+                cmd = KrServices::quote(KDESU_PATH) + " -u " + _action->user() +
+                      " -c " + KrServices::quote(cmd);
             }
         }
         else { // collect output
@@ -312,7 +323,9 @@ void KrActionProc::start(QStringList cmdLineList)
 
             if (!_action->user().isEmpty()) {
                 // "-t" is necessary that kdesu displays the terminal-output of the command
-                cmd = "kdesu -t -u " + _action->user() + " -c " + KrServices::quote(cmd);
+                cmd = KrServices::quote(KDESU_PATH) +
+                      " -t -u " + _action->user() +
+                      " -c " + KrServices::quote(cmd);
             }
         }
         //printf("cmd: %s\n", cmd.toAscii().data());
@@ -682,4 +695,3 @@ QDomElement KrAction::dumpAvailability(QDomDocument& doc) const
 
                     return availabilityElement;
 } //KrAction::dumpAvailability
-
