@@ -49,9 +49,6 @@
 #include <KIconThemes/KIconLoader>
 #include <KWidgetsAddons/KToggleAction>
 #include <KWidgetsAddons/KMessageBox>
-#include <KXmlGui/KEditToolBar>
-#include <KXmlGui/KShortcutsDialog>
-#include <KXmlGui/KToolBar>
 
 #ifdef __KJSEMBED__
 #include <kjsembed/jsconsolewidget.h>
@@ -78,24 +75,22 @@
 #include "GUI/syncbrowsebutton.h"
 #include "GUI/mediabutton.h"
 #include "GUI/dirhistorybutton.h"
-#include "VFS/krquery.h"
+#include "FileSystem/krquery.h"
 #include "Search/krsearchmod.h"
 #include "Search/krsearchdialog.h"
 #include "Locate/locate.h"
-#include "VFS/vfs.h"
-#include "VFS/vfile.h"
+#include "FileSystem/filesystem.h"
+#include "FileSystem/fileitem.h"
 #include "panelmanager.h"
 #include "Splitter/splittergui.h"
 #include "Splitter/splitter.h"
 #include "Splitter/combiner.h"
 #include "ActionMan/actionman.h"
-#include "UserMenu/usermenu.h"
 #include "Panel/panelpopup.h"
 #include "Dialogs/krspecialwidgets.h"
 #include "DiskUsage/diskusagegui.h"
 #include "krservices.h"
 #include "Panel/krviewitem.h"
-#include "Queue/queuedialog.h"
 #include "krtrashhandler.h"
 #include "BookMan/krbookmarkhandler.h"
 #include "BookMan/krbookmarkbutton.h"
@@ -167,26 +162,23 @@ void KRslots::sendFileByEmail(const QList<QUrl> &urls)
 
 void KRslots::compareContent()
 {
-    QStringList lstLeft, lstRight;
-    QStringList* lstActive;
+    const QStringList lstLeft = LEFT_PANEL->getSelectedNames();
+    const QStringList lstRight = RIGHT_PANEL->getSelectedNames();
+    const QStringList lstActive = ACTIVE_PANEL->gui->isLeft() ? lstLeft : lstRight;
     QUrl name1, name2;
 
-    LEFT_PANEL->getSelectedNames(&lstLeft);
-    RIGHT_PANEL->getSelectedNames(&lstRight);
-    lstActive = (ACTIVE_PANEL->gui->isLeft() ? &lstLeft : &lstRight);
-
     if (lstLeft.count() == 1 && lstRight.count() == 1) {
         // first, see if we've got exactly 1 selected file in each panel:
-        name1 = LEFT_PANEL->func->files()->vfs_getFile(lstLeft[0]);
-        name2 = RIGHT_PANEL->func->files()->vfs_getFile(lstRight[0]);
-    } else if (lstActive->count() == 2) {
+        name1 = LEFT_PANEL->func->files()->getUrl(lstLeft[0]);
+        name2 = RIGHT_PANEL->func->files()->getUrl(lstRight[0]);
+    } else if (lstActive.count() == 2) {
         // next try: are in the current panel exacty 2 files selected?
-        name1 = ACTIVE_PANEL->func->files()->vfs_getFile((*lstActive)[0]);
-        name2 = ACTIVE_PANEL->func->files()->vfs_getFile((*lstActive)[1]);
-    } else if (ACTIVE_PANEL->otherPanel()->func->files()->vfs_search(ACTIVE_VIEW->getCurrentItem())) {
+        name1 = ACTIVE_PANEL->func->files()->getUrl(lstActive[0]);
+        name2 = ACTIVE_PANEL->func->files()->getUrl(lstActive[1]);
+    } else if (ACTIVE_PANEL->otherPanel()->func->files()->getFileItem(ACTIVE_VIEW->getCurrentItem())) {
         // next try: is in the other panel a file with the same name?
-        name1 = ACTIVE_PANEL->func->files()->vfs_getFile(ACTIVE_VIEW->getCurrentItem());
-        name2 = ACTIVE_PANEL->otherPanel()->func->files()->vfs_getFile(ACTIVE_VIEW->getCurrentItem());
+        name1 = ACTIVE_PANEL->func->files()->getUrl(ACTIVE_VIEW->getCurrentItem());
+        name2 = ACTIVE_PANEL->otherPanel()->func->files()->getUrl(ACTIVE_VIEW->getCurrentItem());
     } else  {
         // if we got here, then we can't be sure what file to diff
         KMessageBox::detailedError(0, i18n("Do not know which files to compare."), "<qt>" + i18n("To compare two files by content, you can either:<ul><li>Select one file in the left panel, and one in the right panel.</li><li>Select exactly two files in the active panel.</li><li>Make sure there is a file in the other panel, with the same name as the current file in the active panel.</li></ul>") + "</qt>");
@@ -269,17 +261,14 @@ void KRslots::toggleCmdline()
     else MAIN_VIEW->cmdLine()->show();
 }
 
-void KRslots::toggleStatusbar()
+void KRslots::updateStatusbarVisibility()
 {
-    if (krApp->statusBar()->isVisible())
-        krApp->statusBar()->hide();
-    else krApp->statusBar()->show();
+    krApp->statusBar()->setVisible(KrActions::actShowStatusBar->isChecked());
 }
 
 void KRslots::toggleTerminal()
 {
-    if (MAIN_VIEW->terminalDock()->isVisible()) MAIN_VIEW->slotTerminalEmulator(false);
-    else MAIN_VIEW->slotTerminalEmulator(true);
+    MAIN_VIEW->setTerminalEmulator(KrActions::actToggleTerminal->isChecked());
 }
 
 void KRslots::insertFileName(bool full_path)
@@ -290,7 +279,8 @@ void KRslots::insertFileName(bool full_path)
     }
 
     if (full_path) {
-        QString path = vfs::ensureTrailingSlash(ACTIVE_FUNC->files()->vfs_getOrigin()).toDisplayString(QUrl::PreferLocalFile);
+        const QString path = FileSystem::ensureTrailingSlash(ACTIVE_PANEL->virtualPath())
+                                 .toDisplayString(QUrl::PreferLocalFile);
         filename = path + filename;
     }
 
@@ -304,7 +294,7 @@ void KRslots::insertFileName(bool full_path)
         MAIN_VIEW->cmdLine()->setFocus();
     } else if (MAIN_VIEW->terminalDock()->isTerminalVisible()) {
         filename = QChar(' ') + filename + QChar(' ');
-        MAIN_VIEW->terminalDock()->sendInput(filename);
+        MAIN_VIEW->terminalDock()->sendInput(filename, false);
         MAIN_VIEW->terminalDock()->setFocus();
     }
 }
@@ -332,7 +322,7 @@ void KRslots::configChanged(bool isGUIRestartNeeded)
     if (isGUIRestartNeeded) {
         krApp->setUpdatesEnabled(false);
         KConfigGroup group(krConfig, "Look&Feel");
-        vfile::vfile_loadUserDefinedFolderIcons(group.readEntry("Load User Defined Folder Icons", _UserDefinedFolderIcons));
+        FileItem::loadUserDefinedFolderIcons(group.readEntry("Load User Defined Folder Icons", _UserDefinedFolderIcons));
 
         bool leftActive = ACTIVE_PANEL->gui->isLeft();
         MAIN_VIEW->leftManager()->slotRecreatePanels();
@@ -353,8 +343,8 @@ void KRslots::configChanged(bool isGUIRestartNeeded)
 
     if (showHidden != KrActions::actToggleHidden->isChecked()) {
         KrActions::actToggleHidden->setChecked(showHidden);
-        MAIN_VIEW->leftManager()->refreshAllTabs(true);
-        MAIN_VIEW->rightManager()->refreshAllTabs(true);
+        MAIN_VIEW->leftManager()->refreshAllTabs();
+        MAIN_VIEW->rightManager()->refreshAllTabs();
     }
 }
 
@@ -363,14 +353,14 @@ void KRslots::showHiddenFiles(bool show)
     KConfigGroup group(krConfig, "Look&Feel");
     group.writeEntry("Show Hidden", show);
 
-    MAIN_VIEW->leftManager()->refreshAllTabs(true);
-    MAIN_VIEW->rightManager()->refreshAllTabs(true);
+    MAIN_VIEW->leftManager()->refreshAllTabs();
+    MAIN_VIEW->rightManager()->refreshAllTabs();
 }
 
 void KRslots::swapPanels()
 {
-    QUrl leftURL = LEFT_PANEL->func->files()->vfs_getOrigin();
-    QUrl rightURL = RIGHT_PANEL->func->files()->vfs_getOrigin();
+    QUrl leftURL = LEFT_PANEL->virtualPath();
+    QUrl rightURL = RIGHT_PANEL->virtualPath();
 
     LEFT_PANEL->func->openUrl(rightURL);
     RIGHT_PANEL->func->openUrl(leftURL);
@@ -442,15 +432,6 @@ void KRslots::homeTerminal()
     runTerminal(QDir::homePath());
 }
 
-void KRslots::sysInfo()
-{
-    KProcess proc;
-    proc << KrServices::fullPathName("kcmshell") << "System/ksysctrl";
-    if (!proc.startDetached()) {
-        KMessageBox::sorry(krApp, i18n("Cannot find \"KsysCtrl\". Please install KDE admin package"));
-    }
-}
-
 void KRslots::multiRename()
 {
     QStringList lst = KrServices::supportedTools();
@@ -461,74 +442,62 @@ void KRslots::multiRename()
     }
     QString pathToRename = lst[i+1];
 
-    QStringList names;
-    ACTIVE_PANEL->gui->getSelectedNames(&names);
-    QList<QUrl> urls = ACTIVE_FUNC->files()->vfs_getFiles(names);
-
-    if (urls.isEmpty()) {
+    const QStringList names = ACTIVE_PANEL->gui->getSelectedNames();
+    if (names.isEmpty()) {
         return;
     }
 
     KProcess proc;
     proc << pathToRename;
 
-    foreach (const QUrl &url, urls) {
-        if (QFileInfo(url.path()).isDir()) proc << "-r";
-        proc << url.path();
+    for (const QString name: names) {
+        FileItem *file = ACTIVE_FUNC->files()->getFileItem(name);
+        if (!file)
+            continue;
+        const QUrl url = file->getUrl();
+        // KRename only supports the recursive option combined with a local directory path
+        if (file->isDir() && url.scheme() == "file") {
+            proc << "-r" << url.path();
+        } else {
+            proc << url.toString();
+        }
     }
 
     if (!proc.startDetached())
-        KMessageBox::error(0, i18n("Error executing %1.", pathToRename));
+        KMessageBox::error(0, i18n("Error executing '%1'.", proc.program().join(" ")));
 }
 
 void KRslots::rootKrusader()
 {
-    if (!KrServices::cmdExist("krusader") || !KrServices::cmdExist("kdesu")) {
-        KMessageBox::sorry(krApp, i18n("Cannot start root mode Krusader, because Krusader or kdesu is missing from the path. Please configure the dependencies in Konfigurator."));
+    if (KMessageBox::warningContinueCancel(
+            krApp, i18n("Improper operations in root mode can damage your operating system. "
+                        "<p>Furthermore, running UI applications as root is insecure and can "
+                        "allow attackers to gain root access."),
+            QString(), KStandardGuiItem::cont(), KStandardGuiItem::cancel(), "Confirm Root Mode",
+            KMessageBox::Notify | KMessageBox::Dangerous) != KMessageBox::Continue)
+        return;
+
+    if (!KrServices::isExecutable(KDESU_PATH)) {
+        KMessageBox::sorry(krApp,
+            i18n("Cannot start root mode Krusader, %1 not found or not executable. "
+                 "Please verify that kde-cli-tools are installed.", QString(KDESU_PATH)));
         return;
     }
 
     KProcess proc;
-    proc << KrServices::fullPathName("kdesu") << "-c" << KrServices::fullPathName("krusader")
-    + " --left=" + KrServices::quote(LEFT_PANEL->func->files()->vfs_getOrigin().toDisplayString(QUrl::PreferLocalFile))
-    + " --right=" + KrServices::quote(RIGHT_PANEL->func->files()->vfs_getOrigin().toDisplayString(QUrl::PreferLocalFile));
+    proc << KDESU_PATH << "-c" << QApplication::instance()->applicationFilePath()
+    + " --left=" + KrServices::quote(LEFT_PANEL->virtualPath().toDisplayString(QUrl::PreferLocalFile))
+    + " --right=" + KrServices::quote(RIGHT_PANEL->virtualPath().toDisplayString(QUrl::PreferLocalFile));
 
     if (!proc.startDetached())
         KMessageBox::error(0, i18n("Error executing %1.", proc.program()[0]));
 }
 
-// settings slots
-void KRslots::configToolbar()
-{
-    KConfigGroup cg(KSharedConfig::openConfig(), QString());
-    krApp->saveMainWindowSettings(cg);
-    QPointer<KEditToolBar> dlg = new KEditToolBar(krApp->factory());
-    connect(dlg, SIGNAL(newToolBarConfig()), this, SLOT(saveNewToolbarConfig()));
-    if (dlg->exec()) {
-        krApp->updateGUI();
-    }
-    delete dlg;
-}
-
-void KRslots::saveNewToolbarConfig()
-{
-    KConfigGroup cg(KSharedConfig::openConfig(), QString());
-    krApp->applyMainWindowSettings(cg);
-    krApp->updateGUI();
-}
-
-void KRslots::configKeys()
-{
-    KShortcutsDialog::configure(krApp->actionCollection(), KShortcutsEditor::LetterShortcutsAllowed, krMainWindow);
-}
-
 void KRslots::slotSplit()
 {
-    QStringList list;
+    const QStringList list = ACTIVE_PANEL->gui->getSelectedNames();
     QString name;
 
-    ACTIVE_PANEL->gui->getSelectedNames(&list);
-
     // first, see if we've got exactly 1 selected file, if not, try the current one
     if (list.count() == 1) name = list[0];
 
@@ -538,20 +507,20 @@ void KRslots::slotSplit()
         return;
     }
 
-    QUrl fileURL = ACTIVE_FUNC->files()->vfs_getFile(name);
+    QUrl fileURL = ACTIVE_FUNC->files()->getUrl(name);
     if (fileURL.isEmpty())
         return;
 
-    if (ACTIVE_FUNC->files()->vfs_search(name)->vfile_isDir()) {
+    if (ACTIVE_FUNC->files()->getFileItem(name)->isDir()) {
         KMessageBox::sorry(krApp, i18n("You cannot split a folder."));
         return ;
     }
 
-    QUrl destDir = ACTIVE_PANEL->otherPanel()->func->files()->vfs_getOrigin();
+    const QUrl destDir = ACTIVE_PANEL->otherPanel()->virtualPath();
 
     SplitterGUI splitterGUI(MAIN_VIEW, fileURL, destDir);
 
-    if (splitterGUI.result() == QDialog::Accepted) {
+    if (splitterGUI.exec() == QDialog::Accepted) {
         bool splitToOtherPanel = splitterGUI.getDestinationDir().matches(ACTIVE_PANEL->otherPanel()->virtualPath(),
                                                                          QUrl::StripTrailingSlash);
 
@@ -565,26 +534,25 @@ void KRslots::slotSplit()
 
 void KRslots::slotCombine()
 {
-    QStringList   list;
+    const QStringList list = ACTIVE_PANEL->gui->getSelectedNames();
+    if (list.isEmpty()) {
+        KMessageBox::error(0, i18n("Do not know which files to combine."));
+        return;
+    }
+
     QUrl          baseURL;
     bool          unixStyle = false;
     bool          windowsStyle = false;
     QString       commonName;
     int           commonLength = 0;
 
-    ACTIVE_PANEL->gui->getSelectedNames(&list);
-    if (list.isEmpty()) {
-        KMessageBox::error(0, i18n("Do not know which files to combine."));
-        return;
-    }
-
     /* checking splitter names */
-    for (QStringList::Iterator it = list.begin(); it != list.end(); ++it) {
-        QUrl url = ACTIVE_FUNC->files()->vfs_getFile(*it);
+    for (QStringList::ConstIterator it = list.begin(); it != list.end(); ++it) {
+        QUrl url = ACTIVE_FUNC->files()->getUrl(*it);
         if (url.isEmpty())
             return;
 
-        if (ACTIVE_FUNC->files()->vfs_search(*it)->vfile_isDir()) {
+        if (ACTIVE_FUNC->files()->getFileItem(*it)->isDir()) {
             KMessageBox::sorry(krApp, i18n("You cannot combine a folder."));
             return ;
         }
@@ -638,11 +606,11 @@ void KRslots::slotCombine()
                             QString shorter  = commonName.left(commonName.length() - 1);
                             QString testFile = shorter.leftJustified(commonLength, fillLetter);
 
-                            if (ACTIVE_FUNC->files()->vfs_search(testFile) == 0)
+                            if (ACTIVE_FUNC->files()->getFileItem(testFile) == 0)
                                 break;
                             else {
                                 commonName = shorter;
-                                baseURL = ACTIVE_FUNC->files()->vfs_getOrigin().adjusted(QUrl::StripTrailingSlash);
+                                baseURL = ACTIVE_PANEL->virtualPath().adjusted(QUrl::StripTrailingSlash);
                                 baseURL.setPath(baseURL.path() + '/' + (testFile));
                             }
                         }
@@ -674,13 +642,6 @@ void KRslots::slotCombine()
         ACTIVE_PANEL->otherPanel()->func->refresh();
 }
 
-void KRslots::userMenu()
-{
-    //UserMenu um;
-    //um.exec();
-    krApp->userMenu->exec();
-}
-
 void KRslots::manageUseractions()
 {
     ActionMan actionMan(MAIN_VIEW);
@@ -689,8 +650,7 @@ void KRslots::manageUseractions()
 #ifdef SYNCHRONIZER_ENABLED
 void KRslots::slotSynchronizeDirs(QStringList selected)
 {
-    new SynchronizerGUI(0, LEFT_PANEL->func->files()->vfs_getOrigin(),
-                        RIGHT_PANEL->func->files()->vfs_getOrigin(), selected);
+    new SynchronizerGUI(0, LEFT_PANEL->virtualPath(), RIGHT_PANEL->virtualPath(), selected);
 }
 #endif
 
@@ -721,12 +681,7 @@ void KRslots::execTypeSetup()
 
 void KRslots::slotDiskUsage()
 {
-    DiskUsageGUI du(ACTIVE_FUNC->files()->vfs_getOrigin(), MAIN_VIEW);
-}
-
-void KRslots::slotQueueManager()
-{
-    QueueDialog::showDialog(false);
+    DiskUsageGUI du(ACTIVE_PANEL->virtualPath(), MAIN_VIEW);
 }
 
 void KRslots::applicationStateChanged()
@@ -734,12 +689,13 @@ void KRslots::applicationStateChanged()
     if (MAIN_VIEW == 0) {  /* CRASH FIX: it's possible that the method is called after destroying the main view */
         return;
     }
-    if(qApp->applicationState() == Qt::ApplicationActive) {
-        LEFT_PANEL->panelActive();
-        RIGHT_PANEL->panelActive();
+    if(qApp->applicationState() == Qt::ApplicationActive ||
+       qApp->applicationState() == Qt::ApplicationInactive) {
+        LEFT_PANEL->panelVisible();
+        RIGHT_PANEL->panelVisible();
     } else {
-        LEFT_PANEL->panelInactive();
-        RIGHT_PANEL->panelInactive();
+        LEFT_PANEL->panelHidden();
+        RIGHT_PANEL->panelHidden();
     }
 }
 
@@ -751,7 +707,7 @@ void KRslots::emptyTrash()
 #define OPEN_ID        100001
 #define EMPTY_TRASH_ID 100002
 
-void KRslots::trashBin()
+void KRslots::trashPopupMenu()
 {
     QMenu trashMenu(krApp);
     QAction * act = trashMenu.addAction(krLoader->loadIcon("document-open", KIconLoader::Panel), i18n("Open trash bin"));
