@@ -82,7 +82,6 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include "UserAction/kraction.h"
 #include "UserAction/expander.h"
 #include "UserAction/useraction.h"
-#include "UserMenu/usermenu.h"
 #include "Dialogs/popularurls.h"
 #include "Dialogs/checksumdlg.h"
 #include "Dialogs/krpleasewait.h"
@@ -91,13 +90,13 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include "GUI/kcmdline.h"
 #include "GUI/terminaldock.h"
 #include "GUI/krusaderstatus.h"
-#include "VFS/vfile.h"
-#include "VFS/krpermhandler.h"
+#include "FileSystem/fileitem.h"
+#include "FileSystem/krpermhandler.h"
 #include "MountMan/kmountman.h"
-#include "Queue/queue_mgr.h"
 #include "Konfigurator/kgprotocols.h"
 #include "BookMan/krbookmarkhandler.h"
 #include "KViewer/krviewer.h"
+#include "JobMan/jobman.h"
 
 
 #ifdef __KJSEMBED__
@@ -108,7 +107,6 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 // define the static members
 Krusader *Krusader::App = 0;
 QString   Krusader::AppName;
-UserMenu *Krusader::userMenu = 0;
 // KrBookmarkHandler *Krusader::bookman = 0;
 //QTextOStream *Krusader::_krOut = QTextOStream(::stdout);
 
@@ -120,7 +118,7 @@ QAction *Krusader::actShowJSConsole = 0;
 // construct the views, statusbar and menu bars and prepare Krusader to start
 Krusader::Krusader(const QCommandLineParser &parser) : KParts::MainWindow(0,
                 Qt::Window | Qt::WindowTitleHint | Qt::WindowContextHelpButtonHint),
-        status(0), _listPanelActions(0), isStarting(true), isExiting(false)
+        _listPanelActions(0), isStarting(true), isExiting(false)
 {
     // create the "krusader"
     App = this;
@@ -154,14 +152,15 @@ Krusader::Krusader(const QCommandLineParser &parser) : KParts::MainWindow(0,
 
     // create MountMan
     KrGlobal::mountMan = new KMountMan(this);
-    connect(KrGlobal::mountMan, SIGNAL(refreshPanel(const QUrl &)), SLOTS, SLOT(refresh(const QUrl &)));
+    connect(KrGlobal::mountMan, SIGNAL(refreshPanel(QUrl)), SLOTS, SLOT(refresh(QUrl)));
 
     // create bookman
     krBookMan = new KrBookmarkHandler(this);
 
-    _popularUrls = new PopularUrls(this);
+    // create job manager
+    krJobMan = new JobMan(this);
 
-    queueManager = new QueueManager(this);
+    _popularUrls = new PopularUrls(this);
 
     // create the main view
     MAIN_VIEW = new KrusaderView(this);
@@ -175,13 +174,9 @@ Krusader::Krusader(const QCommandLineParser &parser) : KParts::MainWindow(0,
     // init the protocol handler
     KgProtocols::init();
 
-    // init the checksum tools
-    initChecksumModule();
-
     KConfigGroup gl(krConfig, "Look&Feel");
-    KConfigGroup glgen(krConfig, "General");
-    vfile::vfile_loadUserDefinedFolderIcons(gl.readEntry("Load User Defined Folder Icons", _UserDefinedFolderIcons));
-    vfile::vfile_enableMimeTypeMagic(glgen.readEntry("Mimetype Magic", _MimetypeMagic));
+    FileItem::loadUserDefinedFolderIcons(gl.readEntry("Load User Defined Folder Icons",
+                                                         _UserDefinedFolderIcons));
 
     KConfigGroup gs(krConfig, "Startup");
     QString     startProfile = gs.readEntry("Starter Profile Name", QString());
@@ -208,16 +203,26 @@ Krusader::Krusader(const QCommandLineParser &parser) : KParts::MainWindow(0,
     // starting the panels
     MAIN_VIEW->start(gs, startProfile.isEmpty(), leftTabs, rightTabs);
 
-    // create the user menu
-    userMenu = new UserMenu(this);
-    userMenu->hide();
-
     // create a status bar
-    status = new KrusaderStatus(this);
+    KrusaderStatus *status = new KrusaderStatus(this);
     setStatusBar(status);
     status->setWhatsThis(i18n("Statusbar will show basic information "
                               "about file below mouse pointer."));
 
+    // create tray icon (even if not shown)
+    sysTray = new QSystemTrayIcon(this);
+    sysTray->setIcon(krLoader->loadIcon(privIcon(), KIconLoader::Panel, 22));
+    QMenu *trayMenu = new QMenu(this);
+    trayMenu->addSection(QGuiApplication::applicationDisplayName()); // show "title"
+    QAction *restoreAction = new QAction(i18n("Restore"), this);
+    connect(restoreAction, SIGNAL(triggered()), SLOT(showFromTray()));
+    trayMenu->addAction(restoreAction);
+    trayMenu->addSeparator();
+    trayMenu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::Quit)));
+    sysTray->setContextMenu(trayMenu);
+    // tray is only visible if main window is hidden, so action is always "show"
+    connect(sysTray, SIGNAL(activated(QSystemTrayIcon::ActivationReason)), SLOT(showFromTray()));
+
     setCentralWidget(MAIN_VIEW);
 
     // manage our keyboard short-cuts
@@ -227,8 +232,40 @@ Krusader::Krusader(const QCommandLineParser &parser) : KParts::MainWindow(0,
 
     if (! startProfile.isEmpty())
         MAIN_VIEW->profiles(startProfile);
-    // let the good times rool :)
-    updateGUI(true);
+
+    // restore gui settings
+    {
+        // now, check if we need to create a konsole_part
+        // call the XML GUI function to draw the UI
+        createGUI(MAIN_VIEW->terminalDock()->part());
+
+        // this needs to be called AFTER createGUI() !!!
+        updateUserActions();
+        _listPanelActions->guiUpdated();
+
+        // not using this. See savePosition()
+        //applyMainWindowSettings();
+
+        const KConfigGroup cfgToolbar(krConfig, "Main Toolbar");
+        toolBar()->applySettings(cfgToolbar);
+
+        const KConfigGroup cfgJobBar(krConfig, "Job Toolbar");
+        toolBar("jobToolBar")->applySettings(cfgJobBar);
+
+        const KConfigGroup cfgActionsBar(krConfig, "Actions Toolbar");
+        toolBar("actionsToolBar")->applySettings(cfgActionsBar);
+
+        // restore toolbars position and visibility
+        const KConfigGroup cfgStartup(krConfig->group("Startup"));
+        restoreState(cfgStartup.readEntry("State", QByteArray()));
+
+        statusBar()->setVisible(cfgStartup.readEntry("Show status bar", _ShowStatusBar));
+
+        MAIN_VIEW->updateGUI(cfgStartup);
+
+        // popular urls
+        _popularUrls->load();
+    }
 
     if (runKonfig)
         SLOTS->runKonfigurator(true);
@@ -241,15 +278,16 @@ Krusader::Krusader(const QCommandLineParser &parser) : KParts::MainWindow(0,
 
     if (!runKonfig) {
         KConfigGroup cfg(krConfig, "Private");
-        if (cfg.readEntry("Maximized", false))
-            KWindowConfig::restoreWindowSize(windowHandle(), cfg);
-        else {
-            move(oldPos = cfg.readEntry("Start Position", _StartPosition));
-            resize(oldSize = cfg.readEntry("Start Size", _StartSize));
-        }
+        move(cfg.readEntry("Start Position", _StartPosition));
+        resize(cfg.readEntry("Start Size", _StartSize));
     }
 
-    show();
+    // view initialized; show window or tray
+    if (gs.readEntry("Start To Tray", _StartToTray)) {
+        sysTray->show();
+    } else {
+        show();
+    }
 
     KrTrashHandler::startWatcher();
     isStarting = false;
@@ -323,22 +361,51 @@ bool Krusader::versionControl()
     return retval;
 }
 
-void Krusader::statusBarUpdate(QString& mess)
+void Krusader::statusBarUpdate(const QString& mess)
 {
-    // change the message on the statusbar for 2 seconds
-    if (status) // ugly!!!! But as statusBar() creates a status bar if there is no, I have to ask status to prevent
-        // the creation of the KDE default status bar instead of KrusaderStatus.
-        statusBar() ->showMessage(mess, 5000);
+    // change the message on the statusbar for 5 seconds
+    if (statusBar()->isVisible())
+        statusBar()->showMessage(mess, 5000);
 }
 
-void Krusader::moveEvent(QMoveEvent *e) {
-    oldPos = e->oldPos();
-    KParts::MainWindow::moveEvent(e);
+void Krusader::showFromTray() {
+    setWindowState((windowState() & ~Qt::WindowMinimized) | Qt::WindowActive);
+    show();
+    sysTray->hide();
 }
 
-void Krusader::resizeEvent(QResizeEvent *e) {
-    oldSize = e->oldSize();
-    KParts::MainWindow::resizeEvent(e);
+void Krusader::changeEvent(QEvent *event) {
+    QMainWindow::changeEvent(event);
+    if (isExiting)
+        return;
+
+    // toggle tray when minimizing (if enabled)
+    if(event->type() == QEvent::WindowStateChange) {
+        if(isMinimized()) {
+            KConfigGroup group(krConfig, "Look&Feel");
+            if (group.readEntry("Minimize To Tray", _MinimizeToTray)) {
+                // TODO tray created again to prevent bug in kf5,
+                // remove this if bug 365105 is resolved
+                sysTray->deleteLater();
+                sysTray = new QSystemTrayIcon(this);
+                sysTray->setIcon(krLoader->loadIcon(privIcon(), KIconLoader::Panel, 22));
+                QMenu *trayMenu = new QMenu(this);
+                trayMenu->addSection(QGuiApplication::applicationDisplayName()); // show "title"
+                QAction *restoreAction = new QAction(i18n("Restore"), this);
+                connect(restoreAction, SIGNAL(triggered()), SLOT(showFromTray()));
+                trayMenu->addAction(restoreAction);
+                trayMenu->addSeparator();
+                trayMenu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::Quit)));
+                sysTray->setContextMenu(trayMenu);
+                connect(sysTray, SIGNAL(activated(QSystemTrayIcon::ActivationReason)), SLOT(showFromTray()));
+
+                sysTray->show();
+                hide();
+            }
+        } else if(isVisible()) {
+            sysTray->hide();
+        }
+    }
 }
 
 bool Krusader::event(QEvent *e) {
@@ -367,46 +434,52 @@ void Krusader::setupActions() {
 
 void Krusader::savePosition() {
     KConfigGroup cfg(krConfig, "Private");
-    cfg.writeEntry("Maximized", isMaximized());
-    if (isMaximized()) {
-        KConfigGroup cg = krConfig->group("Private");
-        KWindowConfig::saveWindowSize(windowHandle(), cg, KConfigGroup::Normal);
-    }
-    else {
-        cfg.writeEntry("Start Position", isMaximized() ? oldPos : pos());
-        cfg.writeEntry("Start Size", isMaximized() ? oldSize : size());
-    }
+    cfg.writeEntry("Start Position", pos());
+    cfg.writeEntry("Start Size", size());
 
     cfg = krConfig->group("Startup");
     MAIN_VIEW->saveSettings(cfg);
 
-    saveMainWindowSettings(cfg);
+    // NOTE: this would save current window state/size, statusbar and settings for each toolbar.
+    // We are not using this and saving everything manually because
+    // - it does not save window position
+    // - window size save/restore does sometimes not work (multi-monitor setup)
+    // - saving the statusbar visibility should be independent from window position and restoring it
+    //   does not work properly.
+    //KConfigGroup cfg = KConfigGroup(&cfg, "MainWindowSettings");
+    //saveMainWindowSettings(cfg);
+    //statusBar()->setVisible(cfg.readEntry("StatusBar", "Enabled") != "Disabled");
 
     krConfig->sync();
 }
 
 void Krusader::saveSettings() {
+    // workaround: revert terminal fullscreen mode before saving widget and toolbar visibility
+    if (MAIN_VIEW->isTerminalEmulatorFullscreen()) {
+        MAIN_VIEW->setTerminalEmulator(false, true);
+    }
+
+    // save toolbar settings
     KConfigGroup cfg(krConfig, "Main Toolbar");
     toolBar()->saveSettings(cfg);
 
+    cfg = krConfig->group("Job Toolbar");
+    toolBar("jobToolBar")->saveSettings(cfg);
+
     cfg = krConfig->group("Actions Toolbar");
     toolBar("actionsToolBar")->saveSettings(cfg);
 
     cfg = krConfig->group("Startup");
+    // save toolbar visibility and position
+    cfg.writeEntry("State", saveState());
+    cfg.writeEntry("Show status bar", statusBar()->isVisible());
 
-    bool rememberpos = cfg.readEntry("Remember Position", _RememberPos);
-    bool uisavesettings = cfg.readEntry("UI Save Settings", _UiSave);
-
-    // save size and position
-    if (rememberpos || uisavesettings)
+    // save panel and window settings
+    if (cfg.readEntry("Remember Position", _RememberPos))
         savePosition();
 
-    // save the gui
-    if (uisavesettings) {
-        cfg = krConfig->group("Startup");
-        cfg.writeEntry("Show status bar", KrActions::actShowStatusBar->isChecked());
-        cfg.writeEntry("Show tool bar", !toolBar()->isHidden());
-        cfg.writeEntry("Show actions tool bar", !toolBar("actionsToolBar")->isHidden());
+    // save the gui components visibility
+    if (cfg.readEntry("UI Save Settings", _UiSave)) {
         cfg.writeEntry("Show FN Keys", KrActions::actToggleFnkeys->isChecked());
         cfg.writeEntry("Show Cmd Line", KrActions::actToggleCmdline->isChecked());
         cfg.writeEntry("Show Terminal Emulator", KrActions::actToggleTerminal->isChecked());
@@ -427,15 +500,13 @@ bool Krusader::queryClose() {
         return true;
     }
 
-    KConfigGroup cfg = krConfig->group("Look&Feel");
-    if (cfg.readEntry("Warn On Exit", _WarnOnExit)) {
-        // If user decides to cancel...
-        if (KMessageBox::warningYesNo(this, i18n("Are you sure you want to quit?"))
-            != KMessageBox::Yes) {
-            // ... stop quit
-            return false;
-        }
-    }
+    const KConfigGroup cfg = krConfig->group("Look&Feel");
+    const bool confirmExit = cfg.readEntry("Warn On Exit", _WarnOnExit);
+
+    // ask user and wait until all KIO::job operations are terminated. Krusader won't exit before
+    // that anyway
+    if (!krJobMan->waitForJobs(confirmExit))
+        return false;
 
     /* First try to close the child windows, because it's the safer
        way to avoid crashes, then close the main window.
@@ -481,7 +552,6 @@ bool Krusader::queryClose() {
 
 void Krusader::acceptClose() {
     saveSettings();
-    krConfig->sync();
 
     emit shutdown();
 
@@ -493,8 +563,6 @@ void Krusader::acceptClose() {
     dbus.unregisterObject("/Instances/" + Krusader::AppName);
 
     isExiting = true; // this will also kill the pending jobs
-
-    return;
 }
 
 // the please wait dialog functions
@@ -521,95 +589,6 @@ void Krusader::updateUserActions() {
     }
 }
 
-void Krusader::updateGUI(bool enforce) {
-    // now, check if we need to create a konsole_part
-    // call the XML GUI function to draw the UI
-    createGUI(MAIN_VIEW->terminalDock()->part());
-
-    // this needs to be called AFTER createGUI() !!!
-    updateUserActions();
-    _listPanelActions->guiUpdated();
-
-    KConfigGroup cfg_toolbar(krConfig, "Main Toolbar");
-    toolBar()->applySettings(cfg_toolbar);
-
-    KConfigGroup cfg_act(krConfig->group("Actions Toolbar"));
-    toolBar("actionsToolBar") ->applySettings(cfg_act);
-
-    KConfigGroup cfg(krConfig, "Startup");
-    if (enforce) {
-        applyMainWindowSettings(KConfigGroup(&cfg, "MainWindowSettings"));
-        // now, hide what need to be hidden
-        toolBar()->setVisible(cfg.readEntry("Show tool bar", _ShowToolBar));
-        toolBar("actionsToolBar")->setVisible(cfg.readEntry("Show actions tool bar", _ShowActionsToolBar));
-        if (!cfg.readEntry("Show status bar", _ShowStatusBar)) {
-            statusBar() ->hide();
-            KrActions::actShowStatusBar->setChecked(false);
-        } else {
-            statusBar() ->show();
-            KrActions::actShowStatusBar->setChecked(true);
-        }
-
-        MAIN_VIEW->updateGUI(cfg);
-    }
-    // popular urls
-    _popularUrls->load();
-}
-
-QString Krusader::getTempDir() {
-    // try to make krusader temp dir
-    KConfigGroup group(krConfig, "General");
-    QString tmpDir = group.readEntry("Temp Directory", _TempDirectory);
-
-    if (! QDir(tmpDir).exists()) {
-        for (int i = 1 ; i != -1 ; i = tmpDir.indexOf('/', i + 1))
-            QDir().mkdir(tmpDir.left(i));
-        QDir().mkdir(tmpDir);
-        chmod(tmpDir.toLocal8Bit(), 0777);
-    }
-
-    // add a secure sub dir under the user UID
-    QString uid;
-    uid.sprintf("%d", getuid());
-    QDir(tmpDir).mkdir(uid);
-    tmpDir = tmpDir + '/' + uid + '/';
-    chmod(tmpDir.toLocal8Bit(), S_IRUSR | S_IWUSR | S_IXUSR);
-    // add a random sub dir to use
-    while (QDir().exists(tmpDir))
-        tmpDir = tmpDir + KRandom::randomString(8);
-    QDir().mkdir(tmpDir);
-
-    if (!QDir(tmpDir).isReadable()) {
-        KMessageBox::error(krApp, i18n("Could not create a temporary folder. Handling of Archives will not be possible until this is fixed."));
-        return QString();
-    }
-    return tmpDir;
-}
-
-QString Krusader::getTempFile() {
-    // try to make krusader temp dir
-    KConfigGroup group(krConfig, "General");
-    QString tmpDir = group.readEntry("Temp Directory", _TempDirectory);
-
-    if (! QDir(tmpDir).exists()) {
-        for (int i = 1 ; i != -1 ; i = tmpDir.indexOf('/', i + 1))
-            QDir().mkdir(tmpDir.left(i));
-        QDir().mkdir(tmpDir);
-        chmod(tmpDir.toLocal8Bit(), 0777);
-    }
-
-    // add a secure sub dir under the user UID
-    QString uid;
-    uid.sprintf("%d", getuid());
-    QDir(tmpDir).mkdir(uid);
-    tmpDir = tmpDir + '/' + uid + '/';
-    chmod(tmpDir.toLocal8Bit(), S_IRUSR | S_IWUSR | S_IXUSR);
-
-    while (QDir().exists(tmpDir))
-        tmpDir = tmpDir + KRandom::randomString(8);
-    return tmpDir;
-}
-
 const char* Krusader::privIcon() {
     if (geteuid())
         return "krusader_user";
