@@ -28,6 +28,9 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <csignal>
+#include <unistd.h>
+
 // QtCore
 #include <QAbstractEventDispatcher>
 #include <QCommandLineOption>
@@ -50,7 +53,7 @@
 #include <KWidgetsAddons/KActionMenu>
 #include <KWindowSystem/KStartupInfo>
 
-#include "../VFS/krarchandler.h"
+#include "../Archive/krarchandler.h"
 
 #include "krusader.h"
 #include "krusaderview.h"
@@ -60,7 +63,7 @@
 #include "defaults.h"
 #include "Panel/krviewfactory.h"
 
-static const char *description = I18N_NOOP("Krusader\nTwin-Panel File Manager for KDE");
+static const char *description = I18N_NOOP("Krusader\nTwin-Panel File Manager by KDE");
 
 static void sigterm_handler(int i)
 {
@@ -129,6 +132,8 @@ int main(int argc, char *argv[])
     }*/
 // ============ end icon-stuff ===========
 
+    // prevent qt5-webengine crashing
+    QApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
 
     // create the application and set application domain so that calls to i18n get strings from right place.
     QApplication app(argc, argv);
@@ -149,6 +154,8 @@ int main(int argc, char *argv[])
              "irc.freenode.net, channel: #krusader"),
         QStringLiteral("https://krusader.org"));
 
+    aboutData.setOrganizationDomain(QByteArray("kde.org"));
+
     aboutData.addAuthor(i18n("Rafi Yanai"), i18n("Author (retired)"), QStringLiteral("yanai@users.sourceforge.net"));
     aboutData.addAuthor(i18n("Shie Erlich"), i18n("Author (retired)"), QStringLiteral("erlich@users.sourceforge.net"));
     aboutData.addAuthor(i18n("Jan Lepper"), i18n("Developer"), QStringLiteral("jan_lepper@gmx.de"), 0);
